import 'dart:convert';
import 'dart:io';

import 'package:flutter/material.dart';
import 'package:http/http.dart' as http;
import 'package:intl/intl.dart';
import '../../services/global_methods.dart';
import '../../services/global_variables.dart';

// ignore: must_be_immutable
class BookInterviewScreen extends StatefulWidget {
  int jobseekerId;
  String jobId;
  String jobName;
  BookInterviewScreen(
      {super.key,
      required this.jobId,
      required this.jobseekerId,
      required this.jobName});

  @override
  State<BookInterviewScreen> createState() => _BookInterviewScreenState();
}

class _BookInterviewScreenState extends State<BookInterviewScreen> {
  DateTime? picked;

  final _globalKey = GlobalKey<FormState>();
  final TextEditingController _address = TextEditingController();
  final TextEditingController _dateTime = TextEditingController();

  @override
  void initState() {
    _dateTime.text = "";
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return SafeArea(
      child: Scaffold(
        backgroundColor: Colors.grey.shade300,
        appBar: AppBar(
          backgroundColor: Colors.orange,
        ),
        body: Center(
            child: Padding(
          padding: const EdgeInsets.all(7.0),
          child: Card(
            color: Colors.white10,
            child: SingleChildScrollView(
              child: Column(
                crossAxisAlignment: CrossAxisAlignment.start,
                children: [
                  const SizedBox(
                    height: 10,
                  ),
                  const Align(
                    alignment: Alignment.center,
                    child: Padding(
                      padding: EdgeInsets.all(8.0),
                      child: Text(
                        "Book Interview Now",
                        style: TextStyle(
                            color: Colors.black,
                            fontSize: 30,
                            fontWeight: FontWeight.bold,
                            fontStyle: FontStyle.italic),
                      ),
                    ),
                  ),
                  const SizedBox(
                    height: 10,
                  ),
                  const Divider(
                    thickness: 1,
                    color: Colors.grey,
                  ),
                  Padding(
                    padding: const EdgeInsets.all(0),
                    child: Form(
                      key: _globalKey,
                      child: Column(
                        crossAxisAlignment: CrossAxisAlignment.start,
                        children: [
                          GlobalMethods.textTitle(label: 'Address :'),
                          GlobalMethods.textFormFields(
                            valuekey: "Address",
                            controller: _address,
                            enabled: true,
                            fct: () {},
                            maxlength: 50,
                          ),
                          GlobalMethods.textTitle(label: 'Date :'),
                          GlobalMethods.textFormFields(
                            valuekey: "Date",
                            controller: _dateTime,
                            enabled: false,
                            fct: () {
                              _selectDateTime();
                            },
                            maxlength: 50,
                          ),
                          const SizedBox(height: 20),
                          InkWell(
                            onTap: () async {
                              if (_globalKey.currentState!.validate()) {
                                await _submitForm();
                              }
                            },
                            child: Center(
                                child: Container(
                              width: 200,
                              height: 50,
                              decoration: BoxDecoration(
                                  borderRadius: BorderRadius.circular(10),
                                  color: Colors.black),
                              child: const Center(
                                child: Text(
                                  "Send",
                                  style: TextStyle(
                                      fontWeight: FontWeight.bold,
                                      color: Colors.white,
                                      fontSize: 18),
                                ),
                              ),
                            )),
                          ),
                          const SizedBox(height: 20),
                        ],
                      ),
                    ),
                  )
                ],
              ),
            ),
          ),
        )),
      ),
    );
  }

  Future<void> _submitForm() async {
    try {
      final url = Uri.parse('$myUrl/api/company/publishInterview');

      final requestBody = {
        "jobseekerId": widget.jobseekerId,
        "companyId": identifier.id,
        "jobId": widget.jobId,
        "date": _dateTime.text,
        "address": _address.text,
        "status": "false",
        "jobName": widget.jobName,
        "companyName": identifier.name,
      };

      ScaffoldMessenger.of(context).showSnackBar(const SnackBar(
        content: Row(
          mainAxisAlignment: MainAxisAlignment.spaceBetween,
          children: [
            Padding(
              padding: EdgeInsets.all(5.0),
              child: Text("Booking..."),
            ),
            CircularProgressIndicator()
          ],
        ),
        duration: Duration(minutes: 1),
      ));

      final response = await http.post(
        url,
        headers: <String, String>{
          'Content-Type': 'application/json; charset=UTF-8',
          HttpHeaders.authorizationHeader: "Bearer ${identifier.token}"
        },
        body: jsonEncode(requestBody),
      );
      if (response.statusCode == 200 || response.statusCode == 201) {
        _showAndPop();
      } else {
        _showFail();
      }
    } catch (error) {
      print(error);
      GlobalMethods.showErrorDialog(error: error.toString(), ctx: context);
    }
  }

  void _showAndPop() {
    Navigator.pop(context);
    ScaffoldMessenger.of(context).hideCurrentSnackBar();
    ScaffoldMessenger.of(context).showSnackBar(const SnackBar(
      content: Text('Interview booked successfully'),
      duration: Duration(seconds: 3),
    ));
  }

  void _showFail() {
    ScaffoldMessenger.of(context).hideCurrentSnackBar();
    ScaffoldMessenger.of(context).showSnackBar(const SnackBar(
      content: Text('There was an error occurred'),
      duration: Duration(seconds: 3),
    ));
  }

  void _selectDateTime() async {
    final selectedDate = await showDatePicker(
      context: context,
      initialDate: DateTime.now(),
      firstDate: DateTime(1900),
      lastDate: DateTime(2100),
    );

    if (selectedDate != null) {
      // ignore: use_build_context_synchronously
      final selectedTime = await showTimePicker(
        context: context,
        initialTime: TimeOfDay.now(),
      );

      if (selectedTime != null) {
        final dateTime = DateTime(
          selectedDate.year,
          selectedDate.month,
          selectedDate.day,
          selectedTime.hour,
          selectedTime.minute,
        );
        final formattedDateTime =
            DateFormat('yyyy-MM-dd\'T\'HH:mm:ss').format(dateTime);
        setState(() {
          _dateTime.text = formattedDateTime;
        });
      }
    }
  }
}
