import 'dart:io';

import 'package:flutter/material.dart';
import 'package:jobportal/data/job_interview.dart';
import 'package:intl/intl.dart';
import 'package:jobportal/services/global_variables.dart';

class JobInterviewDetails extends StatefulWidget {
  JobInterview jobInterview;
  JobInterviewDetails({super.key, required this.jobInterview});

  @override
  State<JobInterviewDetails> createState() => _JobInterviewDetailsState();
}

class _JobInterviewDetailsState extends State<JobInterviewDetails> {
  @override
  void initState() {
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    // Define your color scheme
    const primaryColor = Colors.orange;
    const secondaryColor = Color(0xFF9B9B9B);
    const backgroundColor = Colors.white;

    return SafeArea(
      child: Scaffold(
        appBar: AppBar(
          title: const Text('Interview Details'),
          backgroundColor: primaryColor,
        ),
        body: SingleChildScrollView(
          child: Padding(
            padding: const EdgeInsets.all(16.0),
            child: Column(
              crossAxisAlignment: CrossAxisAlignment.start,
              children: [
                _buildSectionTitle('Interview Details', primaryColor),
                const SizedBox(height: 16.0),
                _buildDetailRow('Date',
                    DateFormat('yyyy-MM-dd').format(widget.jobInterview.date)),
                _buildDetailRow('Time',
                    DateFormat('HH:mm').format(widget.jobInterview.date)),
                _buildDetailRow('Address', widget.jobInterview.address),
                _buildDetailRow('Status',
                    widget.jobInterview.status ? 'Scheduled' : 'Cancelled'),
                const SizedBox(height: 32.0),
                _buildSectionTitle('Jobseeker Details', primaryColor),
                const SizedBox(height: 16.0),
                Row(
                  mainAxisAlignment: MainAxisAlignment.spaceBetween,
                  children: [
                    if (widget.jobInterview.jobseekerImage.isNotEmpty)
                      Padding(
                        padding: const EdgeInsets.only(top: 16.0),
                        child: Center(
                          child: ClipRRect(
                            borderRadius: BorderRadius.circular(8.0),
                            child: Image.network(
                              '$myUrl/api/jobseekers/getImage/${widget.jobInterview.jobseekerImage}',
                              headers: {
                                HttpHeaders.authorizationHeader:
                                    "Bearer ${identifier.token}"
                              },
                              width: 150,
                              height: 150,
                              fit: BoxFit.cover,
                            ),
                          ),
                        ),
                      ),

                    // Column(
                    //   children: [
                    //     Text(widget.jobInterview.jobseekerName),
                    //     Text(widget.jobInterview.jobseekerEmail)
                    //   ],
                    // )
                  ],
                ),
                const SizedBox(
                  height: 15,
                ),
                _buildDetailRow('Name', widget.jobInterview.jobseekerName),
                _buildDetailRow(
                    'Phone', widget.jobInterview.jobseekerPhoneNumber),
                _buildDetailRow('Email', widget.jobInterview.jobseekerEmail),
                _buildDetailRow('Specification',
                    widget.jobInterview.jobseekerSpecificationName),
                _buildDetailRow('Gender', widget.jobInterview.jobseekerGender),
                _buildDetailRow(
                    'Birthdate',
                    DateFormat('yyyy-MM-dd')
                        .format(widget.jobInterview.jobseekerBirthdate)),
                _buildDetailRow(
                    'Address', widget.jobInterview.jobseekerAddress),
              ],
            ),
          ),
        ),
      ),
    );
  }

  Widget _buildSectionTitle(String title, Color color) {
    return Text(
      title,
      style: TextStyle(
        fontSize: 18.0,
        fontWeight: FontWeight.bold,
        color: color,
      ),
    );
  }

  Widget _buildDetailRow(String label, String value) {
    return Padding(
      padding: const EdgeInsets.symmetric(vertical: 8.0),
      child: Row(
        crossAxisAlignment: CrossAxisAlignment.start,
        children: [
          Expanded(
            flex: 2,
            child: Text(
              label,
              style: const TextStyle(
                color: Colors.grey,
                fontWeight: FontWeight.bold,
              ),
            ),
          ),
          const SizedBox(width: 16.0),
          Expanded(
            flex: 3,
            child: Text(
              value,
              style: const TextStyle(
                color: Colors.black,
              ),
            ),
          ),
        ],
      ),
    );
  }
}
