import 'dart:convert';
import 'dart:io';

import 'package:flutter/material.dart';
import 'package:jobportal/UI/interview/company_interviews.dart';
import 'package:jobportal/data/job_application.dart';
import 'package:jobportal/services/global_variables.dart';
import 'package:jobportal/widgets/simple_job_widget.dart';
import 'package:http/http.dart' as http;
import '../../data/job.dart';
import '../../logic/fetch.dart';
import '../../services/global_methods.dart';
import '../company/job_applicants_screen.dart';

class JobDetails extends StatefulWidget {
  final Job job;
  const JobDetails({Key? key, required this.job}) : super(key: key);

  @override
  State<JobDetails> createState() => _JobDetailsState();
}

class _JobDetailsState extends State<JobDetails> {
  bool _isApplied = false;
  late JobApplication? jobApplication;
  @override
  void initState() {
    super.initState();
    setState(() {
      checkIfApplied();
    });
  }

  Future<void> checkIfApplied() async {
    try {
      jobApplication = await Fetch.checkIfApplied(widget.job.id, identifier.id);
      if (jobApplication != null) {
        setState(() {
          _isApplied = true;
        });
      } else {
        setState(() {
          _isApplied = false;
        });
      }
    } catch (error) {
      // ignore: avoid_print
      print(error);
    }
  }

  @override
  Widget build(BuildContext context) {
    return Container(
      child: SafeArea(
        child: Scaffold(
          backgroundColor: Colors.grey.shade300,
          appBar: AppBar(
            backgroundColor: Colors.orange,
            iconTheme: const IconThemeData(color: Colors.black),
            title: const Center(
              child: Text("Job Details"),
            ),
          ),
          body: SingleChildScrollView(
            child: Column(
              children: [
                Padding(
                  padding: const EdgeInsets.all(8.0),
                  child: Column(children: [
                    Card(
                      color: Colors.black12,
                      margin: const EdgeInsets.all(10.0),
                      shape: RoundedRectangleBorder(
                        borderRadius: BorderRadius.circular(10.0),
                      ),
                      child: Padding(
                        padding: const EdgeInsets.all(10.0),
                        child: Column(
                          crossAxisAlignment: CrossAxisAlignment.start,
                          children: [
                            SimpleJobWidget(
                                image: widget.job.image,
                                jobName: widget.job.name,
                                companyName: widget.job.companyName),
                            const Row(
                              crossAxisAlignment: CrossAxisAlignment.center,
                              children: [
                                Expanded(
                                  child: Text(
                                    'Job Details',
                                    style: TextStyle(
                                      color: Colors.orange,
                                      fontSize: 15,
                                      fontWeight: FontWeight.bold,
                                    ),
                                    maxLines: 1,
                                    overflow: TextOverflow.ellipsis,
                                  ),
                                ),
                              ],
                            ),
                            const SizedBox(height: 8.0),
                            Card(
                              color: Colors.white60,
                              margin: EdgeInsets.zero,
                              shape: RoundedRectangleBorder(
                                borderRadius: BorderRadius.circular(10.0),
                              ),
                              child: Padding(
                                padding: const EdgeInsets.all(10.0),
                                child: Column(
                                  crossAxisAlignment: CrossAxisAlignment.start,
                                  children: [
                                    buildIconTextRow(
                                      icon: Icons.info,
                                      text:
                                          'Specification: ${widget.job.specificationName}',
                                    ),
                                    const SizedBox(height: 8.0),
                                    buildIconTextRow(
                                      icon: Icons.school,
                                      text:
                                          'Required Level: ${widget.job.requiredLevel}',
                                    ),
                                    const SizedBox(height: 8.0),
                                    buildIconTextRow(
                                      icon: Icons.timer,
                                      text:
                                          'Experience: ${widget.job.experience}',
                                    ),
                                    const SizedBox(height: 8.0),
                                    buildIconTextRow(
                                      icon: Icons
                                          .access_time, // Add an icon for time type
                                      text:
                                          'Time Type: ${widget.job.timeType}', // Assuming timeType exists in your Job class
                                    ),
                                    const SizedBox(height: 8.0),
                                    buildIconTextRow(
                                      icon: Icons.attach_money,
                                      text:
                                          'Salary: ${widget.job.minSalary}-${widget.job.maxSalary}',
                                    ),
                                  ],
                                ),
                              ),
                            ),
                            const SizedBox(
                              height: 8,
                            ),
                            const Text(
                              'Description',
                              style: TextStyle(
                                color: Colors.orange,
                                fontSize: 15,
                                fontWeight: FontWeight.bold,
                              ),
                              maxLines: 1,
                              overflow: TextOverflow.ellipsis,
                            ),
                            const SizedBox(height: 8.0),
                            Card(
                              color: Colors.white60,
                              margin: EdgeInsets.zero,
                              shape: RoundedRectangleBorder(
                                borderRadius: BorderRadius.circular(10.0),
                              ),
                              child: Container(
                                padding: const EdgeInsets.all(8.0),
                                child: Text(
                                  widget.job.description,
                                  style: const TextStyle(
                                    color: Colors.black,
                                    fontSize: 13,
                                  ),
                                ),
                              ),
                            ),
                            const SizedBox(height: 8.0),
                            const Text(
                              'Contact Us',
                              style: TextStyle(
                                color: Colors.orange,
                                fontSize: 15,
                                fontWeight: FontWeight.bold,
                              ),
                              maxLines: 1,
                              overflow: TextOverflow.ellipsis,
                            ),
                            const SizedBox(height: 8.0),
                            Card(
                              color: Colors.white60,
                              margin: EdgeInsets.zero,
                              shape: RoundedRectangleBorder(
                                borderRadius: BorderRadius.circular(10.0),
                              ),
                              child: Padding(
                                padding: const EdgeInsets.all(10.0),
                                child: Column(
                                  children: [
                                    buildIconTextRow(
                                      icon: Icons.phone,
                                      text:
                                          'Phone: ${widget.job.phone}', // Assuming phone exists in your Job class
                                    ),
                                    const SizedBox(height: 8.0),
                                    buildIconTextRow(
                                      icon: Icons.email,
                                      text:
                                          'Email: ${widget.job.email}', // Assuming email exists in your Job class
                                    ),
                                  ],
                                ),
                              ),
                            ),
                            const SizedBox(height: 8.0),
                          ],
                        ),
                      ),
                    ),
                  ]),
                ),
                showButton(widget.job, context, _isApplied),
                const SizedBox(height: 20.0),
              ],
            ),
          ),
        ),
      ),
    );
  }

  Widget buildIconTextRow({required IconData icon, required String text}) {
    return Container(
      decoration: BoxDecoration(
        border:
            Border(bottom: BorderSide(color: Colors.black.withOpacity(0.1))),
      ),
      padding: const EdgeInsets.symmetric(vertical: 8.0),
      child: Row(
        children: [
          Icon(icon, size: 16.0, color: Colors.blue), // Set icon color to blue
          const SizedBox(width: 8.0),
          Text(
            text,
            style: const TextStyle(
              color: Colors.black,
              fontSize: 13,
            ),
          ),
        ],
      ),
    );
  }

  Widget showButton(Job job, BuildContext context, bool isApplied) {
    int companyIdInt = int.parse(job.companyId);

    return identifier.iscompany == false
        ? ElevatedButton(
            onPressed: () {
              if (isApplied) {
                _deleteApplyForJob();
              } else {
                _ApplyJob();
              }
            },
            style: ElevatedButton.styleFrom(
              backgroundColor: isApplied == false ? Colors.orange : Colors.red,
              padding: const EdgeInsets.symmetric(horizontal: 40, vertical: 10),
            ),
            child: Text(
              isApplied == false ? 'Apply' : 'Disapply',
              style: const TextStyle(
                color: Colors.white,
                fontSize: 15,
              ),
            ),
          )
        : identifier.id == companyIdInt
            ? Row(
                mainAxisAlignment: MainAxisAlignment.spaceEvenly,
                children: [
                  ElevatedButton(
                    onPressed: () {
                      Navigator.push(
                          context,
                          MaterialPageRoute(
                              builder: (context) => ShowApplicantsScreen(
                                    id: job.id,
                                    jobName: job.name,
                                  )));
                    },
                    style: ElevatedButton.styleFrom(
                      backgroundColor: Colors.orange, // Orange color
                      padding: const EdgeInsets.symmetric(
                          horizontal: 40, vertical: 10),
                    ),
                    child: const Text(
                      'Applicants',
                      style: TextStyle(
                        color: Colors.white,
                        fontSize: 15,
                      ),
                    ),
                  ),
                  ElevatedButton(
                    onPressed: () {
                      Navigator.push(
                          context,
                          MaterialPageRoute(
                              builder: (context) => CompanyInterviews(
                                    jobId: int.parse(widget.job.id),
                                  )));
                    },
                    style: ElevatedButton.styleFrom(
                      backgroundColor: Colors.orange, // Orange color
                      padding: const EdgeInsets.symmetric(
                          horizontal: 40, vertical: 10),
                    ),
                    child: const Text(
                      'Interviews',
                      style: TextStyle(
                        color: Colors.white,
                        fontSize: 15,
                      ),
                    ),
                  ),
                ],
              )
            : const SizedBox();
  }

  // ignore: non_constant_identifier_names
  Future<void> _ApplyJob() async {
    showDialog(
      context: context,
      builder: (context) => AlertDialog(
        backgroundColor: Colors.black54,
        title: const Row(
          children: [
            Padding(
              padding: EdgeInsets.all(8.0),
              child: Icon(
                Icons.logout,
                size: 36,
                color: Colors.white,
              ),
            ),
            Padding(
              padding: EdgeInsets.all(8.0),
              child: Text(
                "Apply Job",
                style: TextStyle(color: Colors.white, fontSize: 36),
              ),
            ),
          ],
        ),
        content: const Text(
          "Do you want to apply for this job?",
          style: TextStyle(color: Colors.white, fontSize: 20),
        ),
        actions: [
          TextButton(
              onPressed: () {
                Navigator.canPop(context) ? Navigator.pop(context) : Null;
              },
              child: const Text(
                "No",
                style: TextStyle(color: Colors.green, fontSize: 16),
              )),
          TextButton(
              onPressed: () {
                Navigator.canPop(context) ? Navigator.pop(context) : Null;
                _submitForm();
              },
              child: const Text(
                "Yes",
                style: TextStyle(color: Colors.green, fontSize: 16),
              )),
        ],
      ),
    );
  }

  Future<void> _submitForm() async {
    try {
      final url = Uri.parse('$myUrl/api/jobseekers/publishJobApplication');
      final newJobApplication = {
        'jobName': widget.job.name,
        'companyId': widget.job.companyId,
        'jobSeekerName': identifier.name,
        'jobSeekerId': "${identifier.id}",
        'jobId': widget.job.id,
      };
      final requestBody = newJobApplication;

      ScaffoldMessenger.of(context).showSnackBar(const SnackBar(
        content: Row(
          mainAxisAlignment: MainAxisAlignment.spaceBetween,
          children: [
            Padding(
              padding: EdgeInsets.all(5.0),
              child: Text("Applying..."),
            ),
            CircularProgressIndicator()
          ],
        ),
        duration: Duration(minutes: 1),
      ));
      final response = await http.post(
        url,
        headers: <String, String>{
          'Content-Type': 'application/json; charset=UTF-8',
          HttpHeaders.authorizationHeader: "Bearer ${identifier.token}"
        },
        body: jsonEncode(requestBody),
      );
      if (response.statusCode == 200 || response.statusCode == 201) {
        setState(() {
          checkIfApplied();
          _isApplied = true;
        });
        // ignore: use_build_context_synchronously
        _showPostSuccess(context);
      } else {
        // ignore: use_build_context_synchronously
        _showPostFail(context);
      }
    } catch (error) {
      // ignore: use_build_context_synchronously
      GlobalMethods.showErrorDialog(error: error.toString(), ctx: context);
    }
  }

  void _showPostSuccess(BuildContext context) {
    // Navigator.pop(context);
    ScaffoldMessenger.of(context).hideCurrentSnackBar();
    ScaffoldMessenger.of(context).showSnackBar(const SnackBar(
      content: Text('Job applied successfully'),
      duration: Duration(seconds: 3),
    ));
  }

  void _showPostFail(BuildContext context) {
    // Navigator.pop(context);
    ScaffoldMessenger.of(context).hideCurrentSnackBar();
    ScaffoldMessenger.of(context).showSnackBar(const SnackBar(
      content: Text('There is an error occured !!!'),
      duration: Duration(seconds: 3),
    ));
  }

  Future<void> _submitDeleteForm() async {
    try {
      final url = Uri.parse('$myUrl/api/applicants/delete');
      ScaffoldMessenger.of(context).showSnackBar(const SnackBar(
        content: Row(
          mainAxisAlignment: MainAxisAlignment.spaceBetween,
          children: [
            Padding(
              padding: EdgeInsets.all(5.0),
              child: Text("Disapplying..."),
            ),
            CircularProgressIndicator()
          ],
        ),
        duration: Duration(minutes: 1),
      ));
      final response = await http.delete(
        url,
        headers: <String, String>{
          'Content-Type': 'application/json; charset=UTF-8',
          HttpHeaders.authorizationHeader: "Bearer ${identifier.token}"
        },
        body: jsonEncode(<String, String>{
          'id': jobApplication!.applicantId,
          'jobName': widget.job.name,
          'companyId': widget.job.companyId,
          'jobSeekerName': identifier.name,
        }),
      );
      if (response.statusCode == 200 || response.statusCode == 201) {
        setState(() {
          checkIfApplied();
        });
        _showDeleteSuccess(context);
      } else {
        _showDeleteFail(context);
      }
    } catch (error) {
      GlobalMethods.showErrorDialog(error: error.toString(), ctx: context);
    }
  }

  void _showDeleteSuccess(BuildContext context) {
    ScaffoldMessenger.of(context).hideCurrentSnackBar();
    ScaffoldMessenger.of(context).showSnackBar(const SnackBar(
      content: Text('Job disapplied successfully'),
      duration: Duration(seconds: 3),
    ));
  }

  void _showDeleteFail(BuildContext context) {
    ScaffoldMessenger.of(context).hideCurrentSnackBar();
    ScaffoldMessenger.of(context).showSnackBar(const SnackBar(
      content: Text('There is an error occured !!!'),
      duration: Duration(seconds: 3),
    ));
  }

  void _deleteApplyForJob() {
    showDialog(
      context: context,
      builder: (context) => AlertDialog(
        backgroundColor: Colors.black54,
        title: const Row(
          children: [
            Padding(
              padding: EdgeInsets.all(8.0),
              child: Icon(
                Icons.logout,
                size: 36,
                color: Colors.white,
              ),
            ),
            Padding(
              padding: EdgeInsets.all(8.0),
              child: Text(
                "Disapply",
                style: TextStyle(color: Colors.white, fontSize: 36),
              ),
            ),
          ],
        ),
        content: const Text(
          "Do you want to disapply for this job?",
          style: TextStyle(color: Colors.white, fontSize: 20),
        ),
        actions: [
          TextButton(
              onPressed: () {
                Navigator.canPop(context) ? Navigator.pop(context) : Null;
              },
              child: const Text(
                "No",
                style: TextStyle(color: Colors.green, fontSize: 16),
              )),
          TextButton(
              onPressed: () {
                Navigator.canPop(context) ? Navigator.pop(context) : Null;
                _submitDeleteForm();
              },
              child: const Text(
                "Yes",
                style: TextStyle(color: Colors.green, fontSize: 16),
              )),
        ],
      ),
    );
  }
}
