import 'dart:convert';
import 'package:http/http.dart' as http;
import 'package:flutter/material.dart';

class CreateCVPage extends StatefulWidget {
  @override
  _CreateCVPageState createState() => _CreateCVPageState();
}

class _CreateCVPageState extends State<CreateCVPage> {
  int cvId = 5;
  final GlobalKey<_CreateCVPageState> _createCVPageStateKey =
      GlobalKey<_CreateCVPageState>();
  final ValueNotifier<List<Certificate>> _certificatesNotifier =
      ValueNotifier<List<Certificate>>([]);
  final ValueNotifier<List<Stage>> _stagesNotifier =
      ValueNotifier<List<Stage>>([]);
  final ValueNotifier<List<PreviousWork>> _previousWorksNotifier =
      ValueNotifier<List<PreviousWork>>([]);
  final ValueNotifier<List<Language>> _languageNotifier =
      ValueNotifier<List<Language>>([]);

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: Text('Create CV'),
      ),
      body: Padding(
        padding: EdgeInsets.all(16.0),
        child: KeyedSubtree(
          key: _createCVPageStateKey,
          child: SingleChildScrollView(
            child: Column(
              crossAxisAlignment: CrossAxisAlignment.start,
              children: [
                SizedBox(height: 16.0),
                ExpansionTile(
                  title: Text('Certificates'),
                  children: [
                    _CertificateForm(),
                    ValueListenableBuilder<List<Certificate>>(
                      valueListenable: _certificatesNotifier,
                      builder: (context, certificates, child) {
                        return Column(
                          children: certificates
                              .map((certificate) =>
                                  _CertificateCard(certificate))
                              .toList(),
                        );
                      },
                    ),
                  ],
                ),
                SizedBox(height: 16.0),
                ExpansionTile(
                  title: Text('Stages'),
                  children: [
                    _StageForm(),
                    ValueListenableBuilder<List<Stage>>(
                      valueListenable: _stagesNotifier,
                      builder: (context, stages, child) {
                        return Column(
                          children:
                              stages.map((stage) => _StageCard(stage)).toList(),
                        );
                      },
                    )
                  ],
                ),
                SizedBox(height: 16.0),
                ExpansionTile(
                  title: Text('Previous Works'),
                  children: [
                    _PreviousWorkForm(),
                    ValueListenableBuilder<List<PreviousWork>>(
                      valueListenable: _previousWorksNotifier,
                      builder: (context, previousWorks, child) {
                        return Column(
                          children: previousWorks
                              .map((previousWork) =>
                                  _PreviousWorkCard(previousWork))
                              .toList(),
                        );
                      },
                    )
                  ],
                ),
                SizedBox(height: 16.0),
                ExpansionTile(
                  title: Text('Languages'),
                  children: [
                    _LanguageForm(),
                    ValueListenableBuilder<List<Language>>(
                      valueListenable: _languageNotifier,
                      builder: (context, languages, child) {
                        return Column(
                          children: languages
                              .map((language) => _LanguageCard(language))
                              .toList(),
                        );
                      },
                    )
                  ],
                ),
                SizedBox(height: 16.0),
                ElevatedButton(
                  onPressed: _submitCV,
                  child: Text('Submit CV'),
                ),
              ],
            ),
          ),
        ),
      ),
    );
  }

  Future<void> _submitCV() async {
    print("1");
    final url = Uri.parse('http://172.29.5.166:30834/api/cvs/create');

    // Prepare the body by encoding it to JSON
    final body = jsonEncode({
      'cvId': cvId.toString(),
      'certificates': _certificatesNotifier.value
          .map((cert) => {
                'name': cert.name,
                'issuingOrganization': cert.issuingOrganization,
                'completionDate': cert.completionDate,
              })
          .toList(),
      'stages': _stagesNotifier.value
          .map((stage) => {
                'name': stage.name,
                'institution': stage.institution,
                'fieldOfStudy': stage.fieldOfStudy,
                'duration': stage.duration,
              })
          .toList(),
      'previousWorks': _previousWorksNotifier.value
          .map((work) => {
                'jobTitle': work.jobTitle,
                'company': work.company,
                'duration': work.duration,
                'description': work.description,
              })
          .toList(),
      'languages': _languageNotifier.value
          .map((lang) => {
                'name': lang.name,
                'proficiencyLevel': lang.proficiencyLevel,
              })
          .toList(),
    });

    print("2");

    try {
      print("3");

      final response = await http.post(
        url,
        headers: <String, String>{
          'Content-Type': 'application/json; charset=UTF-8',
          // HttpHeaders.authorizationHeader: "Bearer ${identifier.token}"
        },
        body: body,
      );

      if (response.statusCode == 200) {
        // Request was successful
        print('CV submitted successfully');
      } else {
        // Request failed
        print('Error submitting CV: ${response.statusCode} - ${response.body}');
      }
    } catch (e) {
      print('Error submitting CV: $e');
    }
  }
}

class Certificate {
  final String name;
  final String issuingOrganization;
  final String completionDate;

  Certificate({
    required this.name,
    required this.issuingOrganization,
    required this.completionDate,
  });
}

class Language {
  final String name;
  final String proficiencyLevel;

  Language({
    required this.name,
    required this.proficiencyLevel,
  });
}

class PreviousWork {
  final String jobTitle;
  final String company;
  final String duration;
  final String description;

  PreviousWork({
    required this.jobTitle,
    required this.company,
    required this.duration,
    required this.description,
  });
}

class Stage {
  final String name;
  final String institution;
  final String fieldOfStudy;
  final String duration;

  Stage({
    required this.name,
    required this.institution,
    required this.fieldOfStudy,
    required this.duration,
  });
}

class _CertificateForm extends StatefulWidget {
  @override
  _CertificateFormState createState() => _CertificateFormState();
}

class _CertificateFormState extends State<_CertificateForm> {
  final _formKey = GlobalKey<FormState>();
  final TextEditingController _name = TextEditingController();
  final TextEditingController _issuingOrganization = TextEditingController();
  final TextEditingController _completionDate = TextEditingController();

  @override
  void initState() {
    super.initState();
    _name.text = '';
    _issuingOrganization.text = '';
    _completionDate.text = '';
  }

  // void _saveCertificate() {
  //   if (_formKey.currentState!.validate()) {
  //     _formKey.currentState!.save();
  //     final certificate = Certificate(
  //       name: _name.text,
  //       issuingOrganization: _issuingOrganization.text,
  //       completionDate: _completionDate.text,
  //     );
  //     setState(() {
  //       (context.findAncestorStateOfType<_CreateCVPageState>())!
  //           .certificates
  //           .add(certificate);
  //       _name.text = '';
  //       _issuingOrganization.text = '';
  //       _completionDate.text = '';
  //     });
  //   }
  // }
  void _saveCertificate() {
    if (_formKey.currentState!.validate()) {
      _formKey.currentState!.save();
      final certificate = Certificate(
        name: _name.text,
        issuingOrganization: _issuingOrganization.text,
        completionDate: _completionDate.text,
      );
      setState(() {
        (context.findAncestorStateOfType<_CreateCVPageState>())!
            ._certificatesNotifier
            .value
            .add(certificate);
        (context.findAncestorStateOfType<_CreateCVPageState>())!
            ._certificatesNotifier
            .notifyListeners();
        _name.text = '';
        _issuingOrganization.text = '';
        _completionDate.text = '';
      });
    }
  }

  @override
  Widget build(BuildContext context) {
    return Form(
      key: _formKey,
      child: Column(
        children: [
          TextFormField(
            controller: _name,
            decoration: InputDecoration(hintText: 'Certificate Name'),
            validator: (value) {
              if (value == null || value.isEmpty) {
                return 'Please enter a certificate name';
              }
              return null;
            },
            onSaved: (value) {
              _name.text = value!;
            },
          ),
          TextFormField(
            controller: _issuingOrganization,
            decoration: InputDecoration(hintText: 'Issuing Organization'),
            validator: (value) {
              if (value == null || value.isEmpty) {
                return 'Please enter the issuing organization';
              }
              return null;
            },
            onSaved: (value) {
              _issuingOrganization.text = value!;
            },
          ),
          TextFormField(
            controller: _completionDate,
            decoration: InputDecoration(hintText: 'Completion Date'),
            validator: (value) {
              if (value == null || value.isEmpty) {
                return 'Please enter the completion date';
              }
              return null;
            },
            onSaved: (value) {
              _completionDate.text = value!;
            },
          ),
          ElevatedButton(
            onPressed: _saveCertificate,
            child: Text('Add Certificate'),
          ),
        ],
      ),
    );
  }
}

class _CertificateCard extends StatelessWidget {
  final Certificate certificate;

  _CertificateCard(this.certificate);

  @override
  Widget build(BuildContext context) {
    return Card(
      child: Padding(
        padding: EdgeInsets.all(16.0),
        child: Column(
          crossAxisAlignment: CrossAxisAlignment.start,
          children: [
            Text('Certificate: ${certificate.name}'),
            SizedBox(height: 8.0),
            Text('Issuing Organization: ${certificate.issuingOrganization}'),
            SizedBox(height: 8.0),
            Text('Completion Date: ${certificate.completionDate}'),
          ],
        ),
      ),
    );
  }
}

class _StageForm extends StatefulWidget {
  @override
  _StageFormState createState() => _StageFormState();
}

class _StageFormState extends State<_StageForm> {
  final _formKey = GlobalKey<FormState>();
  final TextEditingController _name = TextEditingController();
  final TextEditingController _institution = TextEditingController();
  final TextEditingController _fieldOfStudy = TextEditingController();
  final TextEditingController _duration = TextEditingController();

  @override
  void initState() {
    // TODO: implement initState
    super.initState();
    _name.text = '';
    _institution.text = '';
    _fieldOfStudy.text = '';
    _duration.text = '';
  }

  void _saveStage() {
    if (_formKey.currentState!.validate()) {
      _formKey.currentState!.save();
      final stage = Stage(
        name: _name.text,
        institution: _institution.text,
        fieldOfStudy: _fieldOfStudy.text,
        duration: _duration.text,
      );
      setState(() {
        (context.findAncestorStateOfType<_CreateCVPageState>())!
            ._stagesNotifier
            .value
            .add(stage); // Clear the form fields

        (context.findAncestorStateOfType<_CreateCVPageState>())!
            ._stagesNotifier
            .notifyListeners();
        _name.text = '';
        _institution.text = '';
        _fieldOfStudy.text = '';
        _duration.text = '';
      });
    }
  }

  @override
  Widget build(BuildContext context) {
    return Form(
      key: _formKey,
      child: Column(
        children: [
          TextFormField(
            controller: _name,
            decoration: InputDecoration(hintText: 'Stage Name'),
            validator: (value) {
              if (value == null || value.isEmpty) {
                return 'Please enter a stage name';
              }
              return null;
            },
            onSaved: (value) {
              _name.text = value!;
            },
          ),
          TextFormField(
            controller: _institution,
            decoration: InputDecoration(hintText: 'Institution'),
            validator: (value) {
              if (value == null || value.isEmpty) {
                return 'Please enter the institution';
              }
              return null;
            },
            onSaved: (value) {
              _institution.text = value!;
            },
          ),
          TextFormField(
            controller: _fieldOfStudy,
            decoration: InputDecoration(hintText: 'Field of Study'),
            validator: (value) {
              if (value == null || value.isEmpty) {
                return 'Please enter the field of study';
              }
              return null;
            },
            onSaved: (value) {
              _fieldOfStudy.text = value!;
            },
          ),
          TextFormField(
            controller: _duration,
            decoration: InputDecoration(hintText: 'Duration'),
            validator: (value) {
              if (value == null || value.isEmpty) {
                return 'Please enter the duration';
              }
              return null;
            },
            onSaved: (value) {
              _duration.text = value!;
            },
          ),
          ElevatedButton(
            onPressed: _saveStage,
            child: Text('Add Stage'),
          ),
        ],
      ),
    );
  }
}

class _StageCard extends StatelessWidget {
  final Stage stage;

  _StageCard(this.stage);

  @override
  Widget build(BuildContext context) {
    return Card(
      child: Padding(
        padding: EdgeInsets.all(16.0),
        child: Column(
          crossAxisAlignment: CrossAxisAlignment.start,
          children: [
            Text('Stage: ${stage.name}'),
            SizedBox(height: 8.0),
            Text('Institution: ${stage.institution}'),
            SizedBox(height: 8.0),
            Text('Field of Study: ${stage.fieldOfStudy}'),
            SizedBox(height: 8.0),
            Text('Duration: ${stage.duration}'),
          ],
        ),
      ),
    );
  }
}

class _PreviousWorkForm extends StatefulWidget {
  @override
  _PreviousWorkFormState createState() => _PreviousWorkFormState();
}

class _PreviousWorkFormState extends State<_PreviousWorkForm> {
  final _formKey = GlobalKey<FormState>();
  final TextEditingController _jobTitle = TextEditingController();
  final TextEditingController _company = TextEditingController();

  final TextEditingController _duration = TextEditingController();
  final TextEditingController _description = TextEditingController();

  @override
  void initState() {
    // TODO: implement initState
    super.initState();
    _jobTitle.text = '';
    _company.text = '';
    _duration.text = '';
    _description.text = '';
  }

  void _savePreviousWork() {
    if (_formKey.currentState!.validate()) {
      _formKey.currentState!.save();
      final previousWork = PreviousWork(
        jobTitle: _jobTitle.text,
        company: _company.text,
        duration: _duration.text,
        description: _description.text,
      );
      setState(() {
        (context.findAncestorStateOfType<_CreateCVPageState>())!
            ._previousWorksNotifier
            .value
            .add(previousWork); // Clear the form fields

        (context.findAncestorStateOfType<_CreateCVPageState>())!
            ._previousWorksNotifier
            .notifyListeners();
        _jobTitle.text = '';
        _company.text = '';
        _duration.text = '';
        _description.text = '';
      });

      // Clear the form fields
    }
  }

  @override
  Widget build(BuildContext context) {
    return Form(
      key: _formKey,
      child: Column(
        children: [
          TextFormField(
            controller: _jobTitle,
            decoration: InputDecoration(hintText: 'Job Title'),
            validator: (value) {
              if (value == null || value.isEmpty) {
                return 'Please enter a job title';
              }
              return null;
            },
            onSaved: (value) {
              _jobTitle.text = value!;
            },
          ),
          TextFormField(
            controller: _company,
            decoration: InputDecoration(hintText: 'Company'),
            validator: (value) {
              if (value == null || value.isEmpty) {
                return 'Please enter the company';
              }
              return null;
            },
            onSaved: (value) {
              _company.text = value!;
            },
          ),
          TextFormField(
            controller: _duration,
            decoration: InputDecoration(hintText: 'Duration'),
            validator: (value) {
              if (value == null || value.isEmpty) {
                return 'Please enter the duration';
              }
              return null;
            },
            onSaved: (value) {
              _duration.text = value!;
            },
          ),
          TextFormField(
            controller: _description,
            decoration: InputDecoration(hintText: 'Description'),
            validator: (value) {
              if (value == null || value.isEmpty) {
                return 'Please enter a description';
              }
              return null;
            },
            onSaved: (value) {
              _description.text = value!;
            },
          ),
          ElevatedButton(
            onPressed: _savePreviousWork,
            child: Text('Add Previous Work'),
          ),
        ],
      ),
    );
  }
}

class _PreviousWorkCard extends StatelessWidget {
  final PreviousWork previousWork;

  _PreviousWorkCard(this.previousWork);

  @override
  Widget build(BuildContext context) {
    return Card(
      child: Padding(
        padding: EdgeInsets.all(16.0),
        child: Column(
          crossAxisAlignment: CrossAxisAlignment.start,
          children: [
            Text('Job Title: ${previousWork.jobTitle}'),
            SizedBox(height: 8.0),
            Text('Company: ${previousWork.company}'),
            SizedBox(height: 8.0),
            Text('Duration: ${previousWork.duration}'),
            SizedBox(height: 8.0),
            Text('Description: ${previousWork.description}'),
          ],
        ),
      ),
    );
  }
}

class _LanguageForm extends StatefulWidget {
  @override
  _LanguageFormState createState() => _LanguageFormState();
}

class _LanguageFormState extends State<_LanguageForm> {
  final _formKey = GlobalKey<FormState>();
  final TextEditingController _name = TextEditingController();
  final TextEditingController _proficiencyLevel = TextEditingController();
  @override
  void initState() {
    // TODO: implement initState
    super.initState();
    _name.text = '';
    _proficiencyLevel.text = '';
  }

  void _saveLanguage() {
    if (_formKey.currentState!.validate()) {
      _formKey.currentState!.save();
      final language = Language(
        name: _name.text,
        proficiencyLevel: _proficiencyLevel.text,
      );
      setState(() {
        (context.findAncestorStateOfType<_CreateCVPageState>())!
            ._languageNotifier
            .value
            .add(language);
        (context.findAncestorStateOfType<_CreateCVPageState>())!
            ._languageNotifier
            .notifyListeners();
        _name.text = '';
        _proficiencyLevel.text = '';
      });
    }
  }

  @override
  Widget build(BuildContext context) {
    return Form(
      key: _formKey,
      child: Column(
        children: [
          TextFormField(
            controller: _name,
            decoration: InputDecoration(hintText: 'Language Name'),
            validator: (value) {
              if (value == null || value.isEmpty) {
                return 'Please enter a language name';
              }
              return null;
            },
            onSaved: (value) {
              _name.text = value!;
            },
          ),
          TextFormField(
            controller: _proficiencyLevel,
            decoration: InputDecoration(hintText: 'Proficiency Level'),
            validator: (value) {
              if (value == null || value.isEmpty) {
                return 'Please enter the proficiency level';
              }
              return null;
            },
            onSaved: (value) {
              _proficiencyLevel.text = value!;
            },
          ),
          ElevatedButton(
            onPressed: _saveLanguage,
            child: Text('Add Language'),
          ),
        ],
      ),
    );
  }
}

class _LanguageCard extends StatelessWidget {
  final Language language;

  _LanguageCard(this.language);

  @override
  Widget build(BuildContext context) {
    return Card(
      child: Padding(
        padding: EdgeInsets.all(16.0),
        child: Column(
          crossAxisAlignment: CrossAxisAlignment.start,
          children: [
            Text('Language: ${language.name}'),
            SizedBox(height: 8.0),
            Text('Proficiency Level: ${language.proficiencyLevel}'),
          ],
        ),
      ),
    );
  }
}
