import 'dart:io';

import 'package:flutter/material.dart';
import 'package:jobportal/data/jobseeker.dart';
import 'package:jobportal/logic/fetch.dart';
import 'package:jobportal/services/global_methods.dart';
import 'package:jobportal/services/global_variables.dart';
import 'package:url_launcher/url_launcher.dart';
import 'package:intl/intl.dart';
import '../../data/cv.dart';
import '../../data/interview.dart';
import '../interview/book_interview_screen.dart';
import 'package:http/http.dart' as http;

// ignore: must_be_immutable
class CVScreen extends StatefulWidget {
  Jobseeker jobseeker;
  String jobName;
  String jobId;
  CVScreen(
      {super.key,
      required this.jobseeker,
      required this.jobId,
      required this.jobName});

  @override
  State<CVScreen> createState() => _CVScreenState();
}

class _CVScreenState extends State<CVScreen> {
  bool _isBooked = false;
  late Interview interview;

  @override
  void initState() {
    super.initState();
    checkIfBooked();
  }

  Future<void> checkIfBooked() async {
    try {
      interview = await Fetch.checkIfBooked(widget.jobId, widget.jobseeker.id);
      if (interview != null) {
        _isBooked = true;
      } else {
        _isBooked = false;
      }
      setState(() {});
    } catch (error) {
      // ignore: avoid_print
      print(error);
    }
  }

  @override
  Widget build(BuildContext context) {
    Size size = MediaQuery.of(context).size;
    return SafeArea(
      child: Scaffold(
        appBar: AppBar(
          leading: IconButton(
            icon: const Icon(
              Icons.close,
              size: 25,
              color: Colors.black,
            ),
            onPressed: () {
              Navigator.pop(context);
            },
          ),
          backgroundColor: Colors.orange,
        ),
        backgroundColor: Colors.grey.shade300,
        body: Container(
          child: FutureBuilder<CV>(
              future: Fetch.getCvById(4),
              builder: (context, snapshot) {
                if (snapshot.hasData) {
                  return SingleChildScrollView(
                    child: Padding(
                      padding: const EdgeInsets.only(top: 8.0),
                      child: Stack(
                        children: [
                          Card(
                            margin: const EdgeInsets.only(
                                right: 15, left: 15, bottom: 30, top: 60),
                            shape: RoundedRectangleBorder(
                                borderRadius: BorderRadius.circular(10)),
                            color: Colors.black54,
                            child: Column(
                              crossAxisAlignment: CrossAxisAlignment.start,
                              children: [
                                const SizedBox(
                                  height: 130,
                                ),
                                Center(
                                  child: Text(
                                    widget.jobseeker.name,
                                    style: const TextStyle(
                                        color: Colors.white, fontSize: 24),
                                  ),
                                ),
                                const SizedBox(
                                  height: 8,
                                ),
                                Center(
                                  child: Text(
                                    widget.jobseeker.specificationName,
                                    style: const TextStyle(
                                        color: Colors.white54, fontSize: 15),
                                  ),
                                ),
                                const SizedBox(height: 8),
                                identifier.iscompany == true
                                    ? Padding(
                                        padding: const EdgeInsets.all(8.0),
                                        child: Center(
                                          child: MaterialButton(
                                            onPressed: () {
                                              if (_isBooked) {
                                                _deleteInterview();
                                              } else {
                                                _bookInterview();
                                              }
                                            },
                                            color: _isBooked
                                                ? Colors.red
                                                : Colors.blueAccent,
                                            shape:
                                                const RoundedRectangleBorder(),
                                            child: Text(
                                              _isBooked
                                                  ? "Remove Interview"
                                                  : "Book Interview",
                                              style: const TextStyle(
                                                color: Colors.white,
                                                fontWeight: FontWeight.bold,
                                              ),
                                            ),
                                          ),
                                        ),
                                      )
                                    : const SizedBox(),
                                const SizedBox(height: 8),
                                const Divider(
                                  thickness: 1,
                                  color: Colors.grey,
                                ),
                                const SizedBox(height: 20),
                                const Padding(
                                  padding: EdgeInsets.all(10),
                                  child: Text("Account Information :",
                                      style: TextStyle(
                                          color: Colors.white54, fontSize: 22)),
                                ),
                                const SizedBox(
                                  height: 10,
                                ),
                                GestureDetector(
                                  onTap: () async {
                                    {
                                      final Uri url = Uri.parse(
                                          "tel:${widget.jobseeker.phoneNumber}");

                                      if (!await launchUrl(url)) {
                                        throw Exception(
                                            'Could not launch ${widget.jobseeker.phoneNumber}');
                                      }
                                    }
                                  },
                                  child: userInfo(
                                      myIcon: Icons.phone,
                                      content: widget.jobseeker.phoneNumber),
                                ),
                                GestureDetector(
                                  onTap: () async {
                                    {
                                      final Uri url = Uri.parse(
                                          "mailto:${widget.jobseeker.email}");

                                      if (!await launchUrl(url)) {
                                        throw Exception(
                                            'Could not launch ${widget.jobseeker.email}');
                                      }
                                    }
                                  },
                                  child: userInfo(
                                      myIcon: Icons.email,
                                      content: widget.jobseeker.email),
                                ),
                                userInfo(
                                    myIcon: Icons.home,
                                    content: widget.jobseeker.address),
                                const Divider(
                                  thickness: 1,
                                  color: Colors.grey,
                                ),
                                const Padding(
                                  padding: EdgeInsets.all(8.0),
                                  child: Text(
                                    "Birthdate",
                                    style: TextStyle(
                                        color: Colors.white70,
                                        fontSize: 20,
                                        fontWeight: FontWeight.bold),
                                  ),
                                ),
                                Padding(
                                  padding: const EdgeInsets.all(8.0),
                                  child: Text(
                                    DateFormat.yMd()
                                        .format(widget.jobseeker.birthdate),
                                    textAlign: TextAlign.justify,
                                    style: const TextStyle(
                                      color: Colors.white54,
                                      fontSize: 14,
                                    ),
                                  ),
                                ),
                                const Padding(
                                  padding: EdgeInsets.all(8.0),
                                  child: Text(
                                    "Gender",
                                    style: TextStyle(
                                        color: Colors.white70,
                                        fontSize: 20,
                                        fontWeight: FontWeight.bold),
                                  ),
                                ),
                                Padding(
                                  padding: const EdgeInsets.all(8.0),
                                  child: Text(
                                    widget.jobseeker.gender,
                                    style: const TextStyle(
                                      color: Colors.white54,
                                      fontSize: 14,
                                    ),
                                  ),
                                ),
                                const SizedBox(
                                  height: 20,
                                ),
                                const Divider(
                                  height: 8,
                                  color: Colors.grey,
                                ),
                                const Padding(
                                  padding: EdgeInsets.all(12.0),
                                  child: Text(
                                    "Certificates:",
                                    style: TextStyle(
                                        color: Colors.white70,
                                        fontSize: 25,
                                        fontWeight: FontWeight.bold),
                                  ),
                                ),
                                GlobalMethods.buildListViewContainer(
                                    ListView.builder(
                                        itemCount:
                                            snapshot.data!.certificates.length,
                                        itemBuilder: (context, index) => Column(
                                              children: [
                                                ListTile(
                                                  leading: CircleAvatar(
                                                    backgroundColor:
                                                        Colors.white,
                                                    radius: 20,
                                                    child: Center(
                                                        child: Text(
                                                      "${index + 1}",
                                                      style: const TextStyle(
                                                          color:
                                                              Colors.black54),
                                                    )),
                                                  ),
                                                  title: Text(
                                                    "${snapshot.data!.certificates[index].name}    --     ${snapshot.data!.certificates[index].issuingOrganization} --  ${snapshot.data!.certificates[index].completionDate}",
                                                    style: const TextStyle(
                                                        color: Colors.grey,
                                                        fontSize: 14),
                                                  ),
                                                ),
                                                const Divider(
                                                  color: Colors.grey,
                                                ),
                                              ],
                                            ))),
                                const Padding(
                                  padding: EdgeInsets.all(12.0),
                                  child: Text(
                                    "Langueges:",
                                    style: TextStyle(
                                        color: Colors.white70,
                                        fontSize: 25,
                                        fontWeight: FontWeight.bold),
                                  ),
                                ),
                                GlobalMethods.buildListViewContainer(
                                    ListView.builder(
                                        itemCount:
                                            snapshot.data!.languages.length,
                                        itemBuilder: (context, index) => Column(
                                              children: [
                                                ListTile(
                                                  leading: CircleAvatar(
                                                    backgroundColor:
                                                        Colors.white,
                                                    radius: 20,
                                                    child: Center(
                                                        child: Text(
                                                      "${index + 1}",
                                                      style: const TextStyle(
                                                          color:
                                                              Colors.black54),
                                                    )),
                                                  ),
                                                  title: Text(
                                                    "${snapshot.data!.languages[index].name}   --  ${snapshot.data!.languages[index].proficiencyLevel}",
                                                    style: const TextStyle(
                                                        color: Colors.grey,
                                                        fontSize: 14),
                                                  ),
                                                ),
                                                const Divider(
                                                  color: Colors.grey,
                                                ),
                                              ],
                                            ))),
                                const Padding(
                                  padding: EdgeInsets.all(12.0),
                                  child: Text(
                                    "Stages:",
                                    style: TextStyle(
                                        color: Colors.white70,
                                        fontSize: 25,
                                        fontWeight: FontWeight.bold),
                                  ),
                                ),
                                GlobalMethods.buildListViewContainer(
                                    ListView.builder(
                                        itemCount: snapshot.data!.stages.length,
                                        itemBuilder: (context, index) => Column(
                                              children: [
                                                ListTile(
                                                  leading: CircleAvatar(
                                                    backgroundColor:
                                                        Colors.white,
                                                    radius: 20,
                                                    child: Center(
                                                        child: Text(
                                                      "${index + 1}",
                                                      style: const TextStyle(
                                                          color:
                                                              Colors.black54),
                                                    )),
                                                  ),
                                                  title: Text(
                                                    "${snapshot.data!.stages[index].name}   -- ${snapshot.data!.stages[index].institution} --  ${snapshot.data!.stages[index].fieldOfStudy} -- ${snapshot.data!.stages[index].duration}",
                                                    style: const TextStyle(
                                                        color: Colors.grey,
                                                        fontSize: 14),
                                                  ),
                                                ),
                                                const Divider(
                                                  color: Colors.grey,
                                                ),
                                              ],
                                            ))),
                                const Padding(
                                  padding: EdgeInsets.all(12.0),
                                  child: Text(
                                    "Previous Works:",
                                    style: TextStyle(
                                        color: Colors.white70,
                                        fontSize: 25,
                                        fontWeight: FontWeight.bold),
                                  ),
                                ),
                                GlobalMethods.buildListViewContainer(
                                    ListView.builder(
                                        itemCount:
                                            snapshot.data!.previousWorks.length,
                                        itemBuilder: (context, index) => Column(
                                              children: [
                                                ListTile(
                                                  leading: CircleAvatar(
                                                    backgroundColor:
                                                        Colors.white,
                                                    radius: 20,
                                                    child: Center(
                                                        child: Text(
                                                      "${index + 1}",
                                                      style: const TextStyle(
                                                          color:
                                                              Colors.black54),
                                                    )),
                                                  ),
                                                  title: Text(
                                                    "${snapshot.data!.previousWorks[index].jobTitle}   -- ${snapshot.data!.previousWorks[index].company} --  ${snapshot.data!.previousWorks[index].duration} -- ${snapshot.data!.previousWorks[index].description}",
                                                    style: const TextStyle(
                                                        color: Colors.grey,
                                                        fontSize: 14),
                                                  ),
                                                ),
                                                const Divider(
                                                  color: Colors.grey,
                                                ),
                                              ],
                                            ))),
                              ],
                            ),
                          ),
                          Positioned(
                            top: 12,
                            left: size.width * 0.3,
                            child: Row(
                              mainAxisAlignment: MainAxisAlignment.center,
                              children: [
                                Container(
                                  width: size.width * 0.4,
                                  height: size.width * 0.4,
                                  decoration: BoxDecoration(
                                    border: Border.all(
                                        width: 2, color: Colors.amber),
                                    shape: BoxShape.circle,
                                  ),
                                  child: ClipOval(
                                    child: Image.network(
                                      '$myUrl/api/jobseekers/getImage/${widget.jobseeker.image}',
                                      fit: BoxFit.fill,
                                    ),
                                  ),
                                ),
                              ],
                            ),
                          )
                        ],
                      ),
                    ),
                  );
                } else {
                  return const Center(child: CircularProgressIndicator());
                }
              }),
        ),
      ),
    );
  }

  Widget userInfo({required IconData myIcon, required String content}) {
    return Padding(
      padding: const EdgeInsets.all(10.0),
      child: Row(
        children: [
          Icon(myIcon, color: Colors.amber),
          const SizedBox(
            width: 10,
          ),
          Text(
            content,
            style: const TextStyle(color: Colors.white54),
          )
        ],
      ),
    );
  }

  _bookInterview() async {
    await Navigator.push(
      context,
      MaterialPageRoute(
        builder: (context) => BookInterviewScreen(
          jobId: widget.jobId,
          jobseekerId: widget.jobseeker.id,
          jobName: widget.jobName,
        ),
      ),
    );
    // checkIfBooked();

    setState(() {
      _isBooked = true;
    });
  }

  void _deleteInterview() {
    showDialog(
      context: context,
      builder: (context) => AlertDialog(
        backgroundColor: Colors.black87,
        title: const Row(
          children: [
            Padding(
              padding: EdgeInsets.all(8.0),
              child: Icon(
                Icons.logout,
                size: 36,
                color: Colors.white,
              ),
            ),
            Padding(
              padding: EdgeInsets.all(8.0),
              child: Text(
                "Delete",
                style: TextStyle(color: Colors.white, fontSize: 36),
              ),
            ),
          ],
        ),
        content: Text(
          "Delete ${widget.jobseeker.name} interview?",
          style: const TextStyle(color: Colors.white, fontSize: 20),
        ),
        actions: [
          TextButton(
              onPressed: () {
                Navigator.canPop(context) ? Navigator.pop(context) : Null;
              },
              child: const Text(
                "No",
                style: TextStyle(color: Colors.green, fontSize: 16),
              )),
          TextButton(
              onPressed: () {
                Navigator.pop(context);
                _deleteSubmitForm();
              },
              child: const Text(
                "Yes",
                style: TextStyle(color: Colors.green, fontSize: 16),
              )),
        ],
      ),
    );
  }

  Future<void> _deleteSubmitForm() async {
    final url = Uri.parse(
        '$myUrl/api/interviews/delete/${interview.id.toString()}/${widget.jobName}');

    ScaffoldMessenger.of(context).showSnackBar(const SnackBar(
      content: Row(
        mainAxisAlignment: MainAxisAlignment.spaceBetween,
        children: [
          Padding(
            padding: EdgeInsets.all(5.0),
            child: Text("Deleteing..."),
          ),
          CircularProgressIndicator()
        ],
      ),
      duration: Duration(minutes: 1),
    ));

    var response = await http.delete(url, headers: {
      HttpHeaders.authorizationHeader: "Bearer ${identifier.token}"
    });

    if (response.statusCode == 200) {
      _justShow();
    } else {
      _showSnack();
    }
  }

  void _justShow() {
    setState(() {
      _isBooked = false;
    });
    ScaffoldMessenger.of(context).hideCurrentSnackBar();
    ScaffoldMessenger.of(context).showSnackBar(const SnackBar(
      content: Text('The interview deleted successfully'),
      duration: Duration(seconds: 3),
    ));
  }

  void _showSnack() {
    ScaffoldMessenger.of(context).hideCurrentSnackBar();
    ScaffoldMessenger.of(context).showSnackBar(const SnackBar(
      content: Text('There was an error occurred'),
      duration: Duration(seconds: 3),
    ));
  }
}
