import 'dart:io';

import 'package:flutter/material.dart';
import 'package:jobportal/data/job_interview.dart';
import 'package:intl/intl.dart';
import 'package:jobportal/data/jobseeker_interview.dart';
import 'package:jobportal/services/global_variables.dart';

class JobseekerInterviewDetails extends StatefulWidget {
  JobseekerInterview jobseekerInterview;
  JobseekerInterviewDetails({super.key, required this.jobseekerInterview});

  @override
  State<JobseekerInterviewDetails> createState() =>
      _JobseekerInterviewDetailsState();
}

class _JobseekerInterviewDetailsState extends State<JobseekerInterviewDetails> {
  @override
  void initState() {
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    // Define your color scheme
    const primaryColor = Colors.orange;

    return SafeArea(
      child: Scaffold(
        backgroundColor: Colors.grey.shade300,
        appBar: AppBar(
          title: const Text('Interview Details'),
          backgroundColor: primaryColor,
        ),
        body: SingleChildScrollView(
          child: Padding(
            padding: const EdgeInsets.all(16.0),
            child: Column(
              crossAxisAlignment: CrossAxisAlignment.start,
              children: [
                _buildSectionTitle('Interview Details', primaryColor),
                const SizedBox(height: 16.0),
                _buildDetailRow(
                    'Date',
                    DateFormat('yyyy-MM-dd')
                        .format(widget.jobseekerInterview.date)),
                _buildDetailRow('Time',
                    DateFormat('HH:mm').format(widget.jobseekerInterview.date)),
                _buildDetailRow('Address', widget.jobseekerInterview.address),
                _buildDetailRow(
                    'Status',
                    widget.jobseekerInterview.status
                        ? 'Scheduled'
                        : 'Cancelled'),
                const SizedBox(height: 32.0),
                _buildSectionTitle('Company Details', primaryColor),
                const SizedBox(height: 16.0),
                Row(
                  mainAxisAlignment: MainAxisAlignment.spaceBetween,
                  children: [
                    if (widget.jobseekerInterview.companyImage.isNotEmpty)
                      Padding(
                        padding: const EdgeInsets.only(top: 16.0),
                        child: Center(
                          child: ClipRRect(
                            borderRadius: BorderRadius.circular(8.0),
                            child: Image.network(
                              '$myUrl/api/company/getImage/${widget.jobseekerInterview.companyImage}',
                              headers: {
                                HttpHeaders.authorizationHeader:
                                    "Bearer ${identifier.token}"
                              },
                              width: 150,
                              height: 150,
                              fit: BoxFit.cover,
                            ),
                          ),
                        ),
                      ),

                    // Column(
                    //   children: [
                    //     Text(widget.jobInterview.jobseekerName),
                    //     Text(widget.jobInterview.jobseekerEmail)
                    //   ],
                    // )
                  ],
                ),
                const SizedBox(
                  height: 15,
                ),
                _buildDetailRow('Name', widget.jobseekerInterview.companyName),
                _buildDetailRow(
                    'Phone', widget.jobseekerInterview.companyPhoneNumber),
                _buildDetailRow(
                    'Email', widget.jobseekerInterview.companyEmail),
                _buildDetailRow(
                    'Address', widget.jobseekerInterview.companyAddress),
                const SizedBox(height: 16.0),
                _buildSectionTitle('Job Details', primaryColor),
                const SizedBox(height: 16.0),
                _buildDetailRow('Name', widget.jobseekerInterview.jobName),
                _buildDetailRow('Specification',
                    widget.jobseekerInterview.jobSpecificationName),
                _buildDetailRow(
                    'Time Type', widget.jobseekerInterview.jobTimeType),
              ],
            ),
          ),
        ),
      ),
    );
  }

  Widget _buildSectionTitle(String title, Color color) {
    return Text(
      title,
      style: TextStyle(
        fontSize: 18.0,
        fontWeight: FontWeight.bold,
        color: color,
      ),
    );
  }

  Widget _buildDetailRow(String label, String value) {
    return Padding(
      padding: const EdgeInsets.symmetric(vertical: 8.0),
      child: Row(
        crossAxisAlignment: CrossAxisAlignment.start,
        children: [
          Expanded(
            flex: 2,
            child: Text(
              label,
              style: const TextStyle(
                color: Colors.black,
                fontWeight: FontWeight.bold,
              ),
            ),
          ),
          const SizedBox(width: 16.0),
          Expanded(
            flex: 3,
            child: Text(
              value,
              style: const TextStyle(
                color: Colors.black,
              ),
            ),
          ),
        ],
      ),
    );
  }
}
