import 'package:flutter/material.dart';
import 'package:jobportal/services/global_variables.dart';
import 'package:jobportal/data/job.dart';
import 'package:jobportal/logic/fetch.dart';
import '../../widgets/jobwidget.dart';

class JobseekerJobsScreen extends StatefulWidget {
// Add the job to the list
  const JobseekerJobsScreen({super.key});

  @override
  State<JobseekerJobsScreen> createState() => _JobseekerJobsScreenState();
}

class _JobseekerJobsScreenState extends State<JobseekerJobsScreen> {
  final TextEditingController _search = TextEditingController();
  String searchQuery = "Search query";
  int x = 0;
  List<Job> jobs = [];
  List<Job> allJobseekerJobs = [];

  @override
  void initState() {
    super.initState();
    fetchAllJobs();
  }

  void fetchAllJobs() async {
    jobs = await Fetch.getAllJobsByJobseekerId(identifier.id);
    allJobseekerJobs = jobs;

    setState(() {});
  }

  Widget _searchField() {
    return TextField(
      controller: _search,
      autocorrect: true,
      decoration: const InputDecoration(
          border: InputBorder.none,
          hintText: "Search for jobs....",
          hintStyle: TextStyle(color: Colors.white)),
      style: const TextStyle(color: Colors.white, fontSize: 16.0),
    );
  }

  void _clearSearch() {
    setState(() {
      _search.clear();
      _updateSearch("");
    });
  }

  Future<void> _updateSearch(String newQuery) async {
    setState(() {
      searchQuery = newQuery;
    });

    if (newQuery.isEmpty) {
      setState(() {
        jobs = allJobseekerJobs;
      });
    } else {
      final updatedJobseekerJobs =
          await Fetch.getJobsByJobseekerIdAndJobName(identifier.id, newQuery);
      setState(() {
        jobs = updatedJobseekerJobs;
      });
    }
  }

  @override
  Widget build(BuildContext context) {
    return Container(
        // decoration: const BoxDecoration(
        //     gradient: LinearGradient(
        //         colors: [Colors.cyan, Colors.greenAccent],
        //         begin: Alignment.centerLeft,
        //         end: Alignment.centerRight,
        //         stops: [0.1, 1])),
        child: SafeArea(
            child: Scaffold(
      backgroundColor: Colors.grey.shade300,
      appBar: AppBar(
        iconTheme: const IconThemeData(color: Colors.black),
        title: _searchField(),
        // flexibleSpace: Container(
        //   decoration: const BoxDecoration(
        //       gradient: LinearGradient(
        //           colors: [Colors.cyan, Colors.greenAccent],
        //           begin: Alignment.centerLeft,
        //           end: Alignment.centerRight,
        //           stops: [0.2, 0.9])),
        // ),
        backgroundColor: Colors.orange,
        actions: [
          IconButton(
              onPressed: () {
                _clearSearch();
              },
              icon: const Icon(Icons.clear)),
          IconButton(
              onPressed: () {
                String searchQuery = _search.text;
                _updateSearch(searchQuery);
              },
              icon: const Icon(Icons.search)),
          // identifier.iscompany == false
          //     ? IconButton(
          //         onPressed: () {
          //           _showFilterDialog();
          //         },
          //         icon: const Icon(Icons.filter_list))
          //     : const SizedBox(),
        ],
      ),
      body: ListView.builder(
        itemCount: jobs.length,
        itemBuilder: (context, index) {
          return ShowJobWidget(job: jobs[index]);
        },
      ),
    )));
  }

  void _showFilterDialog() {
    showDialog(
      context: context,
      builder: (BuildContext context) {
        return AlertDialog(
            title: const Text('Filter Jobs'),
            content: Column(
              mainAxisSize: MainAxisSize.min,
              children: [
                ListTile(
                  title: const Text('Filter by Specification Name'),
                  onTap: () {
                    Navigator.of(context).pop();
                    _filterBySpecificationName();
                  },
                ),
                const SizedBox(
                  height: 8.0,
                  child: Divider(
                    thickness: 1,
                  ),
                ),
                ListTile(
                  title: const Text('Filter by Time Type'),
                  onTap: () {
                    Navigator.of(context).pop();
                    _filterByTimeType();
                  },
                ),
                const SizedBox(
                  height: 8.0,
                  child: Divider(
                    thickness: 1,
                  ),
                ),
                ListTile(
                  title: const Text('Show All Jobs'),
                  onTap: () {
                    Navigator.of(context).pop();
                    setState(() {
                      jobs = allJobseekerJobs;
                    });
                  },
                ),
              ],
            ),
            actions: [
              TextButton(
                onPressed: () {
                  Navigator.of(context).pop();
                },
                child: const Text('Cancel'),
              ),
            ]);
      },
    );
  }

  Future<void> _getJobsBySpecificationName(String specificationName) async {
    jobs = await Fetch.getAllJobsBySpecificationName(specificationName);

    setState(() {});
  }

  Future<void> _getJobsByTimeType(String timeType) async {
    jobs = await Fetch.getAllJobsByTimeType(timeType);

    setState(() {});
  }

  void _filterBySpecificationName() {
    TextEditingController _specificationNameController =
        TextEditingController();
    showDialog(
      context: context,
      builder: (BuildContext context) {
        return AlertDialog(
          title: const Text('Filter by Specification Name'),
          content: TextField(
            controller: _specificationNameController,
            decoration: const InputDecoration(
              hintText: 'Enter specification name',
            ),
          ),
          actions: [
            TextButton(
              onPressed: () {
                Navigator.of(context).pop();
              },
              child: const Text('Cancel'),
            ),
            TextButton(
              onPressed: () {
                String specificationName = _specificationNameController.text;
                _getJobsBySpecificationName(specificationName);
                Navigator.of(context).pop();
              },
              child: const Text('Filter'),
            ),
          ],
        );
      },
    );
  }

  void _filterByTimeType() {
    showDialog(
      context: context,
      builder: (BuildContext context) {
        return AlertDialog(
          title: const Text('Filter by Time Type'),
          content: Column(
            mainAxisSize: MainAxisSize.min,
            children: [
              ListTile(
                title: const Text('Part-time and On-site Work'),
                onTap: () {
                  _getJobsByTimeType('Part-time and On-site Work');
                  Navigator.of(context).pop();
                },
              ),
              ListTile(
                title: const Text('Full-time and On-site Work'),
                onTap: () {
                  _getJobsByTimeType('Full-time and On-site Work');
                  Navigator.of(context).pop();
                },
              ),
              ListTile(
                title: const Text('Part-time and Remotly Work'),
                onTap: () {
                  _getJobsByTimeType('Part-time and Remotly Work');
                  Navigator.of(context).pop();
                },
              ),
              ListTile(
                title: const Text('Full-time and Remotly Work'),
                onTap: () {
                  _getJobsByTimeType('Full-time and Remotly Work');
                  Navigator.of(context).pop();
                },
              ),
            ],
          ),
          actions: [
            TextButton(
              onPressed: () {
                Navigator.of(context).pop();
              },
              child: const Text('Cancel'),
            ),
          ],
        );
      },
    );
  }
}
