import 'dart:io';

import 'package:flutter/material.dart';
import 'package:jobportal/UI/bottom_navigation_bar/jobseeker_bottom_navigation_bar.dart';
import 'package:jobportal/data/jobseeker.dart';
import 'package:jobportal/data/status.dart';
import 'package:jobportal/logic/fetch.dart';
import 'package:jobportal/services/global_methods.dart';
import 'package:jobportal/services/global_variables.dart';
import 'package:url_launcher/url_launcher.dart';
import 'package:intl/intl.dart';
import '../../data/cv.dart';
import 'create_cv.dart';

class JobseekerProfileScreen extends StatefulWidget {
  JobseekerProfileScreen({super.key});

  @override
  State<JobseekerProfileScreen> createState() =>
      _JobseekerProfileScreenScreenState();
}

class _JobseekerProfileScreenScreenState extends State<JobseekerProfileScreen> {
  late Jobseeker jobseeker;
  late CV cv;
  bool isLoading = false;
  bool hasCv = false;

  @override
  void initState() {
    super.initState();
    _fetchJobseekerProfile();
  }

  Future<void> _fetchJobseekerProfile() async {
    try {
      Status status = await Fetch.checkIfHasCv(identifier.id);
      if (status.status) {
        cv = await Fetch.getCvById(identifier.id);
        jobseeker = await Fetch.getJobseekerById(identifier.id);
        setState(() {
          hasCv = true;
          isLoading = false;
        });
      } else {
        jobseeker = await Fetch.getJobseekerById(identifier.id);
        setState(() {
          hasCv = false;
          isLoading = false;
        });
      }
    } catch (e) {
      // Handle any errors that may occur during the fetching process
      print('Error fetching jobseeker profile: $e');
      setState(() {
        isLoading = false;
      });
    }
  }

  @override
  Widget build(BuildContext context) {
    Size size = MediaQuery.of(context).size;
    return Container(
      decoration: const BoxDecoration(
          gradient: LinearGradient(
              colors: [Colors.cyan, Colors.greenAccent],
              begin: Alignment.centerLeft,
              end: Alignment.centerRight,
              stops: [0.2, 0.9])),
      child: SafeArea(
          child: Scaffold(
        bottomNavigationBar: JobseekerBottomNavigationBar(indexNum: 2),
        backgroundColor: Colors.transparent,
        body: isLoading
            ? const Center(
                child: CircularProgressIndicator(),
              )
            : SingleChildScrollView(
                child: Padding(
                  padding: const EdgeInsets.only(top: 8.0),
                  child: Stack(
                    children: [
                      Card(
                        margin: const EdgeInsets.only(
                            right: 15, left: 15, bottom: 30, top: 60),
                        shape: RoundedRectangleBorder(
                            borderRadius: BorderRadius.circular(10)),
                        color: Colors.black54,
                        child: Column(
                          crossAxisAlignment: CrossAxisAlignment.start,
                          children: [
                            const SizedBox(
                              height: 130,
                            ),
                            Center(
                              child: Text(
                                jobseeker.name,
                                style: const TextStyle(
                                    color: Colors.white, fontSize: 24),
                              ),
                            ),
                            const SizedBox(
                              height: 8,
                            ),
                            Center(
                              child: Text(
                                jobseeker.specificationName,
                                style: const TextStyle(
                                    color: Colors.white54, fontSize: 15),
                              ),
                            ),
                            const SizedBox(height: 8),
                            const Divider(
                              thickness: 1,
                              color: Colors.grey,
                            ),
                            const SizedBox(height: 20),
                            const Padding(
                              padding: EdgeInsets.all(10),
                              child: Text("Account Information :",
                                  style: TextStyle(
                                      color: Colors.white54, fontSize: 22)),
                            ),
                            const SizedBox(
                              height: 10,
                            ),
                            GestureDetector(
                              onTap: () async {
                                {
                                  final Uri url =
                                      Uri.parse("tel:${jobseeker.phoneNumber}");

                                  if (!await launchUrl(url)) {
                                    throw Exception(
                                        'Could not launch ${jobseeker.phoneNumber}');
                                  }
                                }
                              },
                              child: userInfo(
                                  myIcon: Icons.phone,
                                  content: jobseeker.phoneNumber),
                            ),
                            GestureDetector(
                              onTap: () async {
                                {
                                  final Uri url =
                                      Uri.parse("mailto:${jobseeker.email}");

                                  if (!await launchUrl(url)) {
                                    throw Exception(
                                        'Could not launch ${jobseeker.email}');
                                  }
                                }
                              },
                              child: userInfo(
                                  myIcon: Icons.email,
                                  content: jobseeker.email),
                            ),
                            userInfo(
                                myIcon: Icons.home, content: jobseeker.address),
                            const Divider(
                              thickness: 1,
                              color: Colors.grey,
                            ),
                            const Padding(
                              padding: EdgeInsets.all(8.0),
                              child: Text(
                                "Birthdate",
                                style: TextStyle(
                                    color: Colors.white70,
                                    fontSize: 20,
                                    fontWeight: FontWeight.bold),
                              ),
                            ),
                            Padding(
                              padding: const EdgeInsets.all(8.0),
                              child: Text(
                                DateFormat.yMd().format(jobseeker.birthdate),
                                textAlign: TextAlign.justify,
                                style: const TextStyle(
                                  color: Colors.white54,
                                  fontSize: 14,
                                ),
                              ),
                            ),
                            const Padding(
                              padding: EdgeInsets.all(8.0),
                              child: Text(
                                "Gender",
                                style: TextStyle(
                                    color: Colors.white70,
                                    fontSize: 20,
                                    fontWeight: FontWeight.bold),
                              ),
                            ),
                            Padding(
                              padding: const EdgeInsets.all(8.0),
                              child: Text(
                                jobseeker.gender,
                                style: const TextStyle(
                                  color: Colors.white54,
                                  fontSize: 14,
                                ),
                              ),
                            ),
                            const SizedBox(
                              height: 20,
                            ),
                            const Divider(
                              height: 8,
                              color: Colors.grey,
                            ),
                            hasCv == true
                                ? Column(
                                    children: [
                                      const Padding(
                                        padding: EdgeInsets.all(12.0),
                                        child: Text(
                                          "Certificates:",
                                          style: TextStyle(
                                              color: Colors.white70,
                                              fontSize: 30,
                                              fontWeight: FontWeight.bold),
                                        ),
                                      ),
                                      GlobalMethods.buildListViewContainer(
                                          ListView.builder(
                                              itemCount: cv.certificates.length,
                                              itemBuilder: (context, index) =>
                                                  Column(
                                                    children: [
                                                      ListTile(
                                                        leading: CircleAvatar(
                                                          backgroundColor:
                                                              Colors.white,
                                                          radius: 20,
                                                          child: Center(
                                                              child: Text(
                                                            "${index + 1}",
                                                            style: const TextStyle(
                                                                color: Colors
                                                                    .black54),
                                                          )),
                                                        ),
                                                        title: Text(
                                                          "${cv.certificates[index].name}    --     ${cv.certificates[index].issuingOrganization} --  ${cv.certificates[index].completionDate}",
                                                          style:
                                                              const TextStyle(
                                                                  color: Colors
                                                                      .grey,
                                                                  fontSize: 14),
                                                        ),
                                                      ),
                                                      const Divider(
                                                        color: Colors.grey,
                                                      ),
                                                    ],
                                                  ))),
                                      const Padding(
                                        padding: EdgeInsets.all(12.0),
                                        child: Text(
                                          "Langueges:",
                                          style: TextStyle(
                                              color: Colors.white70,
                                              fontSize: 30,
                                              fontWeight: FontWeight.bold),
                                        ),
                                      ),
                                      GlobalMethods.buildListViewContainer(
                                          ListView.builder(
                                              itemCount: cv.languages.length,
                                              itemBuilder: (context, index) =>
                                                  Column(
                                                    children: [
                                                      ListTile(
                                                        leading: CircleAvatar(
                                                          backgroundColor:
                                                              Colors.white,
                                                          radius: 20,
                                                          child: Center(
                                                              child: Text(
                                                            "${index + 1}",
                                                            style: const TextStyle(
                                                                color: Colors
                                                                    .black54),
                                                          )),
                                                        ),
                                                        title: Text(
                                                          "${cv.languages[index].name}   --  ${cv.languages[index].proficiencyLevel}",
                                                          style:
                                                              const TextStyle(
                                                                  color: Colors
                                                                      .grey,
                                                                  fontSize: 14),
                                                        ),
                                                      ),
                                                      const Divider(
                                                        color: Colors.grey,
                                                      ),
                                                    ],
                                                  ))),
                                      const Padding(
                                        padding: EdgeInsets.all(12.0),
                                        child: Text(
                                          "Stages:",
                                          style: TextStyle(
                                              color: Colors.white70,
                                              fontSize: 30,
                                              fontWeight: FontWeight.bold),
                                        ),
                                      ),
                                      GlobalMethods.buildListViewContainer(
                                          ListView.builder(
                                              itemCount: cv.stages.length,
                                              itemBuilder: (context, index) =>
                                                  Column(
                                                    children: [
                                                      ListTile(
                                                        leading: CircleAvatar(
                                                          backgroundColor:
                                                              Colors.white,
                                                          radius: 20,
                                                          child: Center(
                                                              child: Text(
                                                            "${index + 1}",
                                                            style: const TextStyle(
                                                                color: Colors
                                                                    .black54),
                                                          )),
                                                        ),
                                                        title: Text(
                                                          "${cv.stages[index].name}   -- ${cv.stages[index].institution} --  ${cv.stages[index].fieldOfStudy} -- ${cv.stages[index].duration}",
                                                          style:
                                                              const TextStyle(
                                                                  color: Colors
                                                                      .grey,
                                                                  fontSize: 14),
                                                        ),
                                                      ),
                                                      const Divider(
                                                        color: Colors.grey,
                                                      ),
                                                    ],
                                                  ))),
                                      const Padding(
                                        padding: EdgeInsets.all(12.0),
                                        child: Text(
                                          "Previous Works:",
                                          style: TextStyle(
                                              color: Colors.white70,
                                              fontSize: 30,
                                              fontWeight: FontWeight.bold),
                                        ),
                                      ),
                                      GlobalMethods.buildListViewContainer(
                                          ListView.builder(
                                              itemCount:
                                                  cv.previousWorks.length,
                                              itemBuilder: (context, index) =>
                                                  Column(
                                                    children: [
                                                      ListTile(
                                                        leading: CircleAvatar(
                                                          backgroundColor:
                                                              Colors.white,
                                                          radius: 20,
                                                          child: Center(
                                                              child: Text(
                                                            "${index + 1}",
                                                            style: const TextStyle(
                                                                color: Colors
                                                                    .black54),
                                                          )),
                                                        ),
                                                        title: Text(
                                                          "${cv.previousWorks[index].jobTitle}   -- ${cv.previousWorks[index].company} --  ${cv.previousWorks[index].duration} -- ${cv.previousWorks[index].description}",
                                                          style:
                                                              const TextStyle(
                                                                  color: Colors
                                                                      .grey,
                                                                  fontSize: 14),
                                                        ),
                                                      ),
                                                      const Divider(
                                                        color: Colors.grey,
                                                      ),
                                                    ],
                                                  )))
                                    ],
                                  )
                                : Column(
                                    mainAxisAlignment: MainAxisAlignment.start,
                                    children: [
                                      const Text(
                                          "you do not have cv, create now"),
                                      Padding(
                                        padding:
                                            const EdgeInsets.only(bottom: 50),
                                        child: MaterialButton(
                                          onPressed: () {
                                            Navigator.push(
                                              context,
                                              MaterialPageRoute(
                                                builder: (context) =>
                                                    CreateCVPage(),
                                              ),
                                            );
                                          },
                                          color: Colors.cyan,
                                          elevation: 8,
                                          shape: RoundedRectangleBorder(
                                            borderRadius:
                                                BorderRadius.circular(13),
                                          ),
                                          child: const Padding(
                                            padding: EdgeInsets.symmetric(
                                                vertical: 14.0),
                                            child: Row(
                                              mainAxisAlignment:
                                                  MainAxisAlignment.center,
                                              children: [
                                                Text(
                                                  "Create",
                                                  style: TextStyle(
                                                    color: Colors.white,
                                                    fontWeight: FontWeight.bold,
                                                    fontSize: 20,
                                                  ),
                                                )
                                              ],
                                            ),
                                          ),
                                        ),
                                      ),
                                    ],
                                  )
                          ],
                        ),
                      ),
                      Positioned(
                        top: 12,
                        left: size.width * 0.3,
                        child: Row(
                          mainAxisAlignment: MainAxisAlignment.center,
                          children: [
                            Container(
                              width: size.width * 0.4,
                              height: size.width * 0.4,
                              decoration: BoxDecoration(
                                border:
                                    Border.all(width: 2, color: Colors.amber),
                                shape: BoxShape.circle,
                              ),
                              child: ClipOval(
                                child: Image.network(
                                  '$myUrl/api/jobseekers/getImage/${jobseeker.image}',
                                  headers: {
                                    HttpHeaders.authorizationHeader:
                                        "Bearer ${identifier.token}"
                                  },
                                  fit: BoxFit.fill,
                                ),
                              ),
                            ),
                          ],
                        ),
                      )
                    ],
                  ),
                ),
              ),
      )),
    );
  }

  Widget userInfo({required IconData myIcon, required String content}) {
    return Padding(
      padding: const EdgeInsets.all(10.0),
      child: Row(
        children: [
          Icon(myIcon, color: Colors.amber),
          const SizedBox(
            width: 10,
          ),
          Text(
            content,
            style: const TextStyle(color: Colors.white54),
          )
        ],
      ),
    );
  }
}
