import 'package:flutter/material.dart';
import 'package:flutter/widgets.dart';

import '../UI/job/job_details.dart';
import '../data/company_job.dart';
import '../data/job.dart';
import '../services/global_variables.dart';

class ShowCompanyJobWidget extends StatefulWidget {
  final CompanyJob job;

  const ShowCompanyJobWidget({Key? key, required this.job}) : super(key: key);

  @override
  State<ShowCompanyJobWidget> createState() => _ShowCompanyJobWidgetState();
}

class _ShowCompanyJobWidgetState extends State<ShowCompanyJobWidget> {
  @override
  Widget build(BuildContext context) {
    Size size = MediaQuery.of(context).size;

    return Padding(
      padding: const EdgeInsets.all(8.0),
      child: GestureDetector(
        onTap: () {
          Job job = Job(
            companyId: widget.job.companyId,
            id: widget.job.id,
            name: widget.job.name,
            description: widget.job.description,
            email: widget.job.email,
            phone: widget.job.phone,
            image: widget.job.image,
            experience: widget.job.experience,
            requiredLevel: widget.job.requiredLevel,
            timeType: widget.job.timeType,
            companyName: widget.job.companyName,
            minSalary: widget.job.minSalary,
            maxSalary: widget.job.maxSalary,
            specificationName: widget.job.specificationName,
          );
          Navigator.push(
            context,
            MaterialPageRoute(
              builder: (context) => JobDetails(job: job),
            ),
          );
        },
        child: Card(
          color: Colors.white24,
          margin: const EdgeInsets.all(10.0),
          shape: RoundedRectangleBorder(
            borderRadius: BorderRadius.circular(10.0),
          ),
          child: Padding(
            padding: const EdgeInsets.all(10.0),
            child: Column(
              crossAxisAlignment: CrossAxisAlignment.start,
              children: [
                Row(
                  children: [
                    //const Icon(Icons.business, size: 24.0, color: Colors.blue),
                    Container(
                      width: size.width * 0.15,
                      height: size.width * 0.15,
                      decoration: BoxDecoration(
                        border: Border.all(width: 2, color: Colors.amber),
                        shape: BoxShape.circle,
                      ),
                      child: ClipOval(
                        child: Image.network(
                          '$myUrl/api/company/getImage/${widget.job.image}',
                          fit: BoxFit.fill,
                          headers: {
                            'Authorization': 'Bearer ${identifier.token}',
                          },
                        ),
                      ),
                    ),
                    const SizedBox(width: 8.0),
                    Expanded(
                      child: Text(
                        widget.job.companyName,
                        style: const TextStyle(
                          color: Colors.black,
                          fontSize: 25,
                          fontWeight: FontWeight.bold,
                        ),
                        maxLines: 1,
                        overflow: TextOverflow.ellipsis,
                      ),
                    ),
                  ],
                ),
                const SizedBox(height: 8.0),
                Card(
                  color: Colors.white60,
                  margin: EdgeInsets.zero,
                  shape: RoundedRectangleBorder(
                    borderRadius: BorderRadius.circular(10.0),
                  ),
                  child: Padding(
                    padding: const EdgeInsets.all(10.0),
                    child: Column(
                      crossAxisAlignment: CrossAxisAlignment.start,
                      children: [
                        buildIconTextRow(
                          icon: Icons.task,
                          text: 'Job: ${widget.job.name}',
                        ),
                        buildIconTextRow(
                          icon: Icons.info,
                          text:
                              'Specification: ${widget.job.specificationName}',
                        ),
                        const SizedBox(height: 8.0),
                        buildIconTextRow(
                          icon: Icons.school,
                          text: 'Required Level: ${widget.job.requiredLevel}',
                        ),
                        const SizedBox(height: 8.0),
                        buildIconTextRow(
                          icon: Icons.timer,
                          text: 'Experience: ${widget.job.experience}',
                        ),
                        const SizedBox(height: 8.0),
                        buildIconTextRow(
                          icon: Icons.access_time,
                          text: 'Time Type: ${widget.job.timeType}',
                        ),
                        const SizedBox(height: 8.0),
                        buildIconTextRow(
                          icon: Icons.attach_money,
                          text:
                              'Salary: ${widget.job.minSalary}-${widget.job.maxSalary}',
                        ),
                      ],
                    ),
                  ),
                ),
                const SizedBox(height: 8.0),
                // Align(
                //   alignment: Alignment.center,
                //   child: Text(
                //     widget.job.name,
                //     style: const TextStyle(
                //       color: Colors.black,
                //       fontSize: 13,
                //       fontWeight: FontWeight.bold,
                //     ),
                //   ),
                // ),
                Row(
                  mainAxisAlignment: MainAxisAlignment.spaceEvenly,
                  children: [
                    Row(
                      mainAxisAlignment: MainAxisAlignment.center,
                      children: [
                        Text(
                          widget.job.applicantsNumber.toString(),
                          style: const TextStyle(
                              fontSize: 15, color: Colors.black),
                        ),
                        const SizedBox(
                          width: 4,
                        ),
                        const Text(
                          "Applicants  ",
                          style: TextStyle(fontSize: 15, color: Colors.black),
                        ),
                        const Icon(Icons.how_to_reg_sharp,
                            size: 15, color: Colors.black)
                      ],
                    ),
                    Row(
                      mainAxisAlignment: MainAxisAlignment.center,
                      children: [
                        Text(
                          widget.job.interviewsNumber.toString(),
                          style: const TextStyle(
                              fontSize: 15, color: Colors.black),
                        ),
                        const SizedBox(
                          width: 4,
                        ),
                        const Text(
                          "Interviews  ",
                          style: TextStyle(fontSize: 15, color: Colors.black),
                        ),
                        const Icon(Icons.book_online,
                            size: 15, color: Colors.black)
                      ],
                    ),
                  ],
                ),
              ],
            ),
          ),
        ),
      ),
    );
  }
}

Widget buildIconTextRow({required IconData icon, required String text}) {
  return Container(
    decoration: BoxDecoration(
      border: Border(bottom: BorderSide(color: Colors.black.withOpacity(0.1))),
    ),
    padding: const EdgeInsets.symmetric(vertical: 8.0),
    child: Row(
      children: [
        Icon(icon, size: 16.0, color: Colors.blue), // Set icon color to blue
        const SizedBox(width: 8.0),
        Text(
          text,
          style: const TextStyle(
            color: Colors.black,
            fontSize: 13,
          ),
        ),
      ],
    ),
  );
}
