import 'package:intl/intl.dart';
import 'package:flutter/material.dart';
import 'package:http/http.dart' as http;
import 'package:jobportal/data/company.dart';
import 'package:jobportal/data/identifier.dart';
import 'package:jobportal/data/jobseeker.dart';
import 'package:jobportal/logic/fetch.dart';
import '../services/global_methods.dart';
import '../data/interview.dart';
import '../services/global_variables.dart';

// ignore: must_be_immutable
class InterviewWidget extends StatefulWidget {
  Interview interview;

  InterviewWidget({super.key, required this.interview});
  @override
  State<InterviewWidget> createState() => _InterviewWidgetState();
}

class _InterviewWidgetState extends State<InterviewWidget> {
  late Company company; // = Company(
  //     id: "0",
  //     name: "name",
  //     phone: "phone",
  //     email: "email",
  //     image: "image",
  //     address: "address",
  //     description: "description");
  late Jobseeker jobseeker; // = Jobseeker(
  // id: 0,
  // address: "address",
  // birthdate: DateTime.parse("2024-06-28"),
  // email: "email",
  // gender: "gender",
  // image: "image",
  // name: "name",
  // phoneNumber: "phoneNumber",
  // specificationName: "specificationName");
  @override
  void initState() {
    super.initState();
    getReleatedData();
  }

  bool isLoading = false;
  Future<void> getReleatedData() async {
    setState(() {
      isLoading = true;
    });

    try {
      identifier.iscompany == true
          ? {
              jobseeker =
                  await Fetch.getJobseekerById(widget.interview.jobseekerId)
            }
          : {company = await Fetch.getCompanyById(widget.interview.companyId)};
    } catch (e) {
      // Handle any errors that may occur during the fetching process
      print('Error fetching releated data: $e');
    } finally {
      setState(() {
        isLoading = false;
      });
    }
  }

  @override
  Widget build(BuildContext context) {
    return Padding(
      padding: const EdgeInsets.all(0),
      child: isLoading
          ? const Center(
              child: CircularProgressIndicator(),
            )
          : Padding(
              padding: const EdgeInsets.all(8.0),
              child: Card(
                color: Colors.white54,
                child: Column(
                  mainAxisAlignment: MainAxisAlignment.start,
                  crossAxisAlignment: CrossAxisAlignment.start,
                  children: [
                    Padding(
                      padding: const EdgeInsets.all(8.0),
                      child: Center(
                        child: Text(
                          (identifier.iscompany == true)
                              ? "Interview with ${jobseeker.name} jobseeker"
                              : "Interview with ${company.name} company",
                          style: const TextStyle(
                              color: Colors.black,
                              fontSize: 17,
                              fontWeight: FontWeight.bold),
                        ),
                      ),
                    ),
                    const Divider(
                      thickness: 1,
                      color: Colors.black,
                    ),
                    SizedBox(
                      width: MediaQuery.of(context).size.width,
                      child: Row(
                        mainAxisAlignment: MainAxisAlignment.start,
                        children: [
                          GestureDetector(
                            onTap: () {
                              // _goToProfile(context);
                            },
                            child: Row(
                              crossAxisAlignment: CrossAxisAlignment.start,
                              children: [
                                Padding(
                                  padding: const EdgeInsets.all(8.0),
                                  child: Container(
                                    decoration: BoxDecoration(
                                      border: Border.all(
                                          width: 3, color: Colors.black),
                                      image: DecorationImage(
                                        image: NetworkImage(
                                          identifier.iscompany == true
                                              ? '$myUrl/api/jobseekers/getImage/${jobseeker.image}'
                                              : '$myUrl/api/company/getImage/${company.image}',
                                          headers: {
                                            'Authorization':
                                                'Bearer ${identifier.token}',
                                          },
                                        ),
                                        fit: BoxFit.fill,
                                      ),
                                    ),
                                    width: 100,
                                    height: 120,
                                  ),
                                ),
                                const SizedBox(
                                  width: 10,
                                ),
                                Padding(
                                  padding: const EdgeInsets.only(top: 8.0),
                                  child: Column(
                                    mainAxisAlignment: MainAxisAlignment.start,
                                    crossAxisAlignment:
                                        CrossAxisAlignment.start,
                                    children: [
                                      Row(
                                        mainAxisAlignment:
                                            MainAxisAlignment.start,
                                        children: [
                                          const Padding(
                                            padding: EdgeInsets.all(5.0),
                                            child: Text(
                                              "Date :",
                                              style: TextStyle(
                                                  color: Colors.black,
                                                  fontSize: 14,
                                                  fontWeight: FontWeight.bold),
                                            ),
                                          ),
                                          Padding(
                                            padding: const EdgeInsets.all(5.0),
                                            child: Text(
                                              DateFormat.yMd().format(
                                                  DateTime.parse(
                                                      (widget.interview.date)
                                                          .toString())),
                                              textAlign: TextAlign.justify,
                                              style: const TextStyle(
                                                color: Colors.black,
                                                fontSize: 14,
                                              ),
                                            ),
                                          ),
                                        ],
                                      ),
                                      Row(
                                        mainAxisAlignment:
                                            MainAxisAlignment.start,
                                        children: [
                                          const Padding(
                                            padding: EdgeInsets.all(5.0),
                                            child: Text(
                                              "Time :",
                                              style: TextStyle(
                                                  color: Colors.black,
                                                  fontSize: 14,
                                                  fontWeight: FontWeight.bold),
                                            ),
                                          ),
                                          Padding(
                                            padding: const EdgeInsets.all(5.0),
                                            child: Text(
                                              DateFormat.Hm().format(
                                                  DateTime.parse(
                                                      (widget.interview.date)
                                                          .toString())),
                                              textAlign: TextAlign.justify,
                                              style: const TextStyle(
                                                color: Colors.black,
                                                fontSize: 14,
                                              ),
                                            ),
                                          ),
                                        ],
                                      ),
                                      Row(
                                        mainAxisAlignment:
                                            MainAxisAlignment.start,
                                        children: [
                                          const Padding(
                                            padding: EdgeInsets.all(5.0),
                                            child: Text(
                                              "Address :",
                                              style: TextStyle(
                                                  color: Colors.black,
                                                  fontSize: 14,
                                                  fontWeight: FontWeight.bold),
                                            ),
                                          ),
                                          Padding(
                                            padding: const EdgeInsets.all(5.0),
                                            child: Text(
                                              widget.interview.address,
                                              textAlign: TextAlign.justify,
                                              style: const TextStyle(
                                                color: Colors.black,
                                                fontSize: 14,
                                              ),
                                            ),
                                          ),
                                        ],
                                      ),
                                      Row(
                                        mainAxisAlignment:
                                            MainAxisAlignment.start,
                                        children: [
                                          const Padding(
                                            padding: EdgeInsets.all(5.0),
                                            child: Text(
                                              "Status :",
                                              style: TextStyle(
                                                  color: Colors.black,
                                                  fontSize: 14,
                                                  fontWeight: FontWeight.bold),
                                            ),
                                          ),
                                          Padding(
                                            padding: const EdgeInsets.all(5.0),
                                            child: Text(
                                              (widget.interview.status)
                                                  .toString(),
                                              textAlign: TextAlign.justify,
                                              style: const TextStyle(
                                                color: Colors.black,
                                                fontSize: 14,
                                              ),
                                            ),
                                          ),
                                        ],
                                      )
                                    ],
                                  ),
                                )
                              ],
                            ),
                          ),
                        ],
                      ),
                    ),
                    const SizedBox(
                      height: 8,
                      child: Divider(
                        color: Colors.black,
                      ),
                    ),
                    const SizedBox(
                      height: 8,
                    ),
                    // Padding(
                    //   padding: const EdgeInsets.all(8.0),
                    //   child: Row(
                    //     mainAxisAlignment: MainAxisAlignment.spaceBetween,
                    //     children: [
                    //       MaterialButton(
                    //         onPressed: () {
                    //           _goToProfile(context);
                    //         },
                    //         color: Colors.blueAccent,
                    //         shape: const RoundedRectangleBorder(),
                    //         child: const Text(
                    //           "Show Profile",
                    //           style: TextStyle(
                    //             color: Colors.white,
                    //             fontWeight: FontWeight.bold,
                    //           ),
                    //         ),
                    //       ),
                    //       const SizedBox(
                    //         width: 20,
                    //       ),
                    //       (identifier.id == widget.interview.companyId &&
                    //               identifier.iscompany == true)
                    //           ? Row(
                    //               children: [
                    //                 IconButton(
                    //                   icon: const Icon(
                    //                     Icons.delete,
                    //                     size: 25,
                    //                     color: Colors.amber,
                    //                   ),
                    //                   onPressed: () async {
                    //                     _deleteInterview(widget.interview.id);
                    //                   },
                    //                 ),
                    //                 IconButton(
                    //                   icon: const Icon(
                    //                     Icons.edit,
                    //                     size: 25,
                    //                     color: Colors.amber,
                    //                   ),
                    //                   onPressed: () async {
                    //                     _editInterview();
                    //                   },
                    //                 ),
                    //               ],
                    //             )
                    //           : const Text(""),
                    //     ],
                    //   ),
                    // )
                  ],
                ),
              ),
            ),
    );
  }

  void _goToProfile(context) {
    showDialog(
      context: context,
      builder: (context) => AlertDialog(
        backgroundColor: Colors.black87,
        title: const Row(
          children: [
            Padding(
              padding: EdgeInsets.all(8.0),
              child: Icon(
                Icons.logout,
                size: 36,
                color: Colors.white,
              ),
            ),
            Padding(
              padding: EdgeInsets.all(8.0),
              child: Text(
                "Move",
                style: TextStyle(color: Colors.white, fontSize: 36),
              ),
            ),
          ],
        ),
        content: const Text(
          "show profile?",
          style: TextStyle(color: Colors.white, fontSize: 20),
        ),
        actions: [
          TextButton(
              onPressed: () {
                Navigator.canPop(context) ? Navigator.pop(context) : Null;
              },
              child: const Text(
                "No",
                style: TextStyle(color: Colors.green, fontSize: 16),
              )),
          TextButton(
              onPressed: () {
                Navigator.canPop(context) ? Navigator.pop(context) : Null;
                //  Navigator.push(
                //     context,
                //     MaterialPageRoute(
                //         builder: (context) =>
                //             (identifier.iscompany == true)
                //                 ? ShowProfileScreen(
                //                     id: widget.interview.jobSeekerId,
                //                   )
                //                 : ShowCompanyProfileScreen(
                //                     id: widget.interview.companyId,
                //                   )));
              },
              child: const Text(
                "Yes",
                style: TextStyle(color: Colors.green, fontSize: 16),
              )),
        ],
      ),
    );
  }

  void _deleteInterview(int id) {
    showDialog(
      context: context,
      builder: (context) => AlertDialog(
        backgroundColor: Colors.black54,
        title: const Row(
          children: [
            Padding(
              padding: EdgeInsets.all(8.0),
              child: Icon(
                Icons.logout,
                size: 36,
                color: Colors.white,
              ),
            ),
            Padding(
              padding: EdgeInsets.all(8.0),
              child: Text(
                "Delete",
                style: TextStyle(color: Colors.white, fontSize: 36),
              ),
            ),
          ],
        ),
        content: const Text(
          "Delete interview?",
          style: TextStyle(color: Colors.white, fontSize: 20),
        ),
        actions: [
          TextButton(
              onPressed: () {
                Navigator.canPop(context) ? Navigator.pop(context) : Null;
              },
              child: const Text(
                "No",
                style: TextStyle(color: Colors.green, fontSize: 16),
              )),
          TextButton(
              onPressed: () {
                Navigator.pop(context);
                try {
                  // _deleteSubmitForm();
                } catch (error) {
                  GlobalMethods.showErrorDialog(
                      error: error.toString(), ctx: context);
                }
              },
              child: const Text(
                "Yes",
                style: TextStyle(color: Colors.green, fontSize: 16),
              )),
        ],
      ),
    );
  }

  void _editInterview() {
    showDialog(
      context: context,
      builder: (context) => AlertDialog(
        backgroundColor: Colors.black54,
        title: const Row(
          children: [
            Padding(
              padding: EdgeInsets.all(8.0),
              child: Icon(
                Icons.logout,
                size: 36,
                color: Colors.white,
              ),
            ),
            Padding(
              padding: EdgeInsets.all(8.0),
              child: Text(
                "Edit",
                style: TextStyle(color: Colors.white, fontSize: 36),
              ),
            ),
          ],
        ),
        content: const Text(
          "Edit interview?",
          style: TextStyle(color: Colors.white, fontSize: 20),
        ),
        actions: [
          TextButton(
              onPressed: () {
                Navigator.canPop(context) ? Navigator.pop(context) : Null;
              },
              child: const Text(
                "No",
                style: TextStyle(color: Colors.green, fontSize: 16),
              )),
          TextButton(
              onPressed: () {
                // Navigator.pop(context);
                // Navigator.pushReplacement(
                //     context,
                //     MaterialPageRoute(
                //         builder: (context) => UpdateInterviewScreen(
                //               id: widget.interview.id,
                //               address: widget.interview.address,
                //               date: widget.interview.date,
                //               jobId: widget.interview.jobId,
                //             )));
              },
              child: const Text(
                "Yes",
                style: TextStyle(color: Colors.green, fontSize: 16),
              )),
        ],
      ),
    );
  }

  // Future<void> _deleteSubmitForm() async {
  //   final url = Uri.parse('$myUrl/api/Interviews/DeleteInterview');
  //   final request = http.MultipartRequest('delete', url)
  //     ..fields['id'] = widget.interview.id.toString()
  //     ..fields['jobSeekerId'] = widget.interview.jobSeekerId.toString()
  //     ..fields['companyId'] = widget.interview.companyId.toString()
  //     ..fields['jobId'] = widget.interview.jobId.toString()
  //     ..fields['date'] = widget.interview.date
  //     ..fields['address'] = widget.interview.address
  //     ..fields['image'] = widget.interview.image
  //     ..fields['name'] = widget.interview.name;
  //   request.headers['Authorization'] = "Bearer ${identifier.token}";
  //   request.headers['Content-Type'] = 'application/json';

  //   // ignore: use_build_context_synchronously
  //   ScaffoldMessenger.of(context).showSnackBar(const SnackBar(
  //     content: Row(
  //       mainAxisAlignment: MainAxisAlignment.spaceBetween,
  //       children: [
  //         Padding(
  //           padding: EdgeInsets.all(5.0),
  //           child: Text("Deleteing..."),
  //         ),
  //         CircularProgressIndicator()
  //       ],
  //     ),
  //     duration: Duration(minutes: 1),
  //   ));

  //   var response = await request.send();

  //   if (response.statusCode == 200) {
  //     _popThenPush();
  //   } else {
  //     _showFail();
  //   }
  // }

  // void _popThenPush() {
  //   Navigator.pushReplacement(
  //       context,
  //       MaterialPageRoute(
  //           builder: (context) =>
  //               ShowInterviewsScreen(id: widget.interview.jobId)));
  //   ScaffoldMessenger.of(context).hideCurrentSnackBar();
  //   ScaffoldMessenger.of(context).showSnackBar(const SnackBar(
  //     content: Text('The interview deleted successfully'),
  //     duration: Duration(seconds: 3),
  //   ));
  // }

  // void _showFail() {
  //   ScaffoldMessenger.of(context).hideCurrentSnackBar();
  //   ScaffoldMessenger.of(context).showSnackBar(const SnackBar(
  //     content: Text('There was an error occurred'),
  //     duration: Duration(seconds: 3),
  //   ));
  // }
}
